<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:acknowledgement:acknowledgementdocument:6:0" xmlns="urn:iec62325.351:tc57wg16:451-1:acknowledgementdocument:7:0" version="1.0" exclude-result-prefixes="org">
	<xsl:output method="xml"/>
	<xsl:template match="org:AcknowledgementDocument|AcknowledgementDocument">
		<Acknowledgement_MarketDocument>
			<xsl:call-template name="MessageIdentification"/>
			<xsl:call-template name="MessageDateTime"/>
			<xsl:call-template name="SenderIdentification"/>
			<xsl:call-template name="SenderRole"/>
			<xsl:call-template name="ReceiverIdentification"/>
			<xsl:call-template name="ReceiverRole"/>
			<xsl:call-template name="ReceivingDocumentIdentification"/>
			<xsl:call-template name="ReceivingDocumentVersion"/>
			<xsl:call-template name="ReceivingDocumentType"/>
			<xsl:call-template name="ReceivingDocumentPayload"/>
			<xsl:call-template name="DateTimeReceivingDocument"/>
			<xsl:call-template name="TimeSeriesRejection"/>
			<xsl:call-template name="Reason"/>
			<xsl:call-template name="TimeIntervalError"/>
		</Acknowledgement_MarketDocument>
	</xsl:template>
	<xsl:template name="TimeSeriesRejection">
		<xsl:for-each select="org:TimeSeriesRejection|TimeSeriesRejection">
			<xsl:element name="Rejected_TimeSeries">
				<xsl:call-template name="SendersTimeSeriesIdentification"/>
				<xsl:call-template name="SendersTimeSeriesVersion"/>
				<xsl:call-template name="TimeIntervalError"/>
				<xsl:call-template name="Reason"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="TimeIntervalError">
		<xsl:for-each select="org:TimeIntervalError|TimeIntervalError">
			<xsl:element name="InError_Period">
				<xsl:call-template name="QuantityTimeInterval"/>
				<xsl:call-template name="Reason"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Reason">
		<xsl:for-each select="org:Reason|Reason">
			<xsl:element name="Reason">
				<xsl:call-template name="ReasonCode"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!-- Attributes ========================= -->
	<xsl:template name="MessageIdentification">
		<xsl:choose>
			<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MessageDateTime">
		<xsl:choose>
			<xsl:when test="count(org:DocumentDateTime/@v|DocumentDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:DocumentDateTime/@v|DocumentDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceivingDocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReceivingDocumentIdentification/@v|ReceivingDocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="received_MarketDocument.mRID">
					<xsl:value-of select="org:ReceivingDocumentIdentification/@v|ReceivingDocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceivingDocumentVersion">
		<xsl:choose>
			<xsl:when test="count(org:ReceivingDocumentVersion/@v|ReceivingDocumentVersion/@v) &gt; 0 ">
				<xsl:element name="received_MarketDocument.revisionNumber">
					<xsl:value-of select="org:ReceivingDocumentVersion/@v|ReceivingDocumentVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceivingDocumentType">
		<xsl:choose>
			<xsl:when test="count(org:ReceivingDocumentType/@v|ReceivingDocumentType/@v) &gt; 0 ">
				<xsl:element name="received_MarketDocument.type">
					<xsl:value-of select="org:ReceivingDocumentType/@v|ReceivingDocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceivingDocumentPayload">
		<xsl:choose>
			<xsl:when test="count(org:ReceivingDocumentPayload/@v|ReceivingDocumentPayload/@v) &gt; 0 ">
				<xsl:element name="received_MarketDocument.title">
					<xsl:value-of select="org:ReceivingDocumentPayload/@v|ReceivingDocumentPayload/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DateTimeReceivingDocument">
		<xsl:choose>
			<xsl:when test="count(org:DateTimeReceivingDocument/@v|DateTimeReceivingDocument/@v) &gt; 0 ">
				<xsl:element name="received_MarketDocument.createdDateTime">
					<xsl:value-of select="org:DateTimeReceivingDocument/@v|DateTimeReceivingDocument/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SenderIdentification">
		<xsl:element name="sender_MarketParticipant.mRID">
			<xsl:attribute name="codingScheme"><xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/></xsl:attribute>
			<xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="SenderRole">
		<xsl:element name="sender_MarketParticipant.marketRole.type">
			<xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="ReceiverIdentification">
		<xsl:element name="receiver_MarketParticipant.mRID">
			<xsl:attribute name="codingScheme"><xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/></xsl:attribute>
			<xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="ReceiverRole">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverRole/@v|ReceiverRole/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ScheduleTimeInterval">
		<xsl:element name="schedule_Time_Period.timeInterval">
			<xsl:element name="start">
				<xsl:value-of select="substring(org:ScheduleTimeInterval/@v|ScheduleTimeInterval/@v,1,17)"/>
			</xsl:element>
			<xsl:element name="end">
				<xsl:value-of select="substring(org:ScheduleTimeInterval/@v|ScheduleTimeInterval/@v,19,17)"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="SendersTimeSeriesIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SendersTimeSeriesIdentification/@v|SendersTimeSeriesIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:SendersTimeSeriesIdentification/@v|SendersTimeSeriesIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SendersTimeSeriesVersion">
		<xsl:choose>
			<xsl:when test="count(org:SendersTimeSeriesVersion/@v|SendersTimeSeriesVersion/@v) &gt; 0 ">
				<xsl:element name="version">
					<xsl:value-of select="org:SendersTimeSeriesVersion/@v|SendersTimeSeriesVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReasonCode">
		<xsl:element name="code">
			<xsl:value-of select="org:ReasonCode/@v|ReasonCode/@v"/>
		</xsl:element>
		<xsl:for-each select="org:ReasonText|ReasonText">
			<xsl:element name="text">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="QuantityTimeInterval">
		<xsl:element name="timeInterval">
			<xsl:element name="start">
				<xsl:value-of select="substring(org:QuantityTimeInterval/@v|QuantityTimeInterval/@v,1,17)"/>
			</xsl:element>
			<xsl:element name="end">
				<xsl:value-of select="substring(org:QuantityTimeInterval/@v|QuantityTimeInterval/@v,19,17)"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>
