<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:ess:confirmationreport:4:1" xmlns="urn:iec62325.351:tc57wg16:451-2:confirmationdocument:5:0" version="1.0" exclude-result-prefixes="org">
	<xsl:output method="xml"/>
	<!--  This xslt convert an ESS confirmation message/document version 2r3, 3r3 and 4r1 to a CIM confirmation document -->
	<xsl:template match="org:ConfirmationReport|ConfirmationReport">
		<Confirmation_MarketDocument>
			<xsl:call-template name="MessageDocument"/>
		</Confirmation_MarketDocument>
	</xsl:template>
	<xsl:template name="MessageDocument">
		<!--  -->
		<xsl:call-template name="MessageIdentification"/>
		<xsl:call-template name="MessageType"/>
		<xsl:call-template name="MessageDateTime"/>
		<xsl:call-template name="DocumentIdentification"/>
		<xsl:call-template name="DocumentType"/>
		<xsl:call-template name="CreationDateTime"/>
		<!--  -->
		<xsl:call-template name="SenderIdentification"/>
		<xsl:call-template name="SenderRole"/>
		<xsl:call-template name="ReceiverIdentification"/>
		<xsl:call-template name="ReceiverRole"/>
		<xsl:call-template name="ScheduleTimeInterval"/>
		<!--  -->
		<xsl:call-template name="ConfirmedMessageIdentification"/>
		<xsl:call-template name="ConfirmedMessageVersion"/>
		<xsl:call-template name="ConfirmedDocumentIdentification"/>
		<xsl:call-template name="ConfirmedDocumentVersion"/>
		<!--  -->
		<xsl:call-template name="Domain"/>
		<xsl:call-template name="SubjectParty"/>
		<xsl:call-template name="SubjectRole"/>
		<xsl:call-template name="ProcessType"/>
		<xsl:call-template name="Reason"/>
		<xsl:call-template name="ImposedTimeSeries"/>
		<xsl:call-template name="TimeSeriesConfirmation"/>
	</xsl:template>
	<xsl:template name="ImposedTimeSeries">
		<xsl:for-each select="org:ImposedTimeSeries|ImposedTimeSeries">
			<xsl:element name="Imposed_TimeSeries">
				<xsl:call-template name="ImposedTimeSeriesIdentification"/>
				<xsl:call-template name="ImposedTimeSeriesVersion"/>
				<xsl:call-template name="ContentTimeSeries"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="TimeSeriesConfirmation">
		<xsl:for-each select="org:TimeSeriesConfirmation|TimeSeriesConfirmation">
			<xsl:element name="Confirmed_TimeSeries">
				<xsl:call-template name="SendersTimeSeriesIdentification"/>
				<xsl:call-template name="SendersTimeSeriesVersion"/>
				<xsl:call-template name="ContentTimeSeries"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="ContentTimeSeries">
		<xsl:call-template name="BusinessType"/>
		<xsl:call-template name="Product"/>
		<xsl:call-template name="ObjectAggregation"/>
		<xsl:call-template name="InArea"/>
		<xsl:call-template name="OutArea"/>
		<xsl:call-template name="MeteringPointIdentification"/>
		<xsl:call-template name="InParty"/>
		<xsl:call-template name="OutParty"/>
		<xsl:call-template name="CapacityContractType"/>
		<xsl:call-template name="CapacityAgreementIdentification"/>
		<xsl:call-template name="MeasurementUnit"/>
		<xsl:call-template name="CurveType"/>
		<!--  -->
		<xsl:call-template name="Period"/>
		<xsl:call-template name="Reason"/>
	</xsl:template>
	<xsl:template name="Period">
		<xsl:for-each select="org:Period|Period">
			<xsl:element name="Period">
				<xsl:call-template name="TimeInterval"/>
				<xsl:call-template name="Resolution"/>
				<xsl:call-template name="Interval"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Interval">
		<xsl:for-each select="org:Interval|Interval">
			<xsl:element name="Point">
				<xsl:call-template name="Pos"/>
				<xsl:call-template name="Qty"/>
				<xsl:call-template name="Reason"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Reason">
		<xsl:for-each select="org:Reason|Reason">
			<xsl:element name="Reason">
				<xsl:call-template name="ReasonCode"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!-- -->
	<xsl:template name="MessageIdentification">
		<xsl:choose>
			<xsl:when test="count(org:MessageIdentification/@v|MessageIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:MessageIdentification/@v|MessageIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MessageType">
		<xsl:choose>
			<xsl:when test="count(org:MessageType/@v|MessageType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:MessageType/@v|MessageType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DocumentType">
		<xsl:choose>
			<xsl:when test="count(org:DocumentType/@v|DocumentType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:DocumentType/@v|DocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!--    -->
	<xsl:template name="MessageDateTime">
		<xsl:choose>
			<xsl:when test="count(org:MessageDateTime/@v|MessageDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:MessageDateTime/@v|MessageDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="CreationDateTime">
		<xsl:choose>
			<xsl:when test="count(org:CreationDateTime/@v|CreationDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:CreationDateTime/@v|CreationDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!--    -->
	<xsl:template name="SenderIdentification">
		<xsl:element name="sender_MarketParticipant.mRID">
			<xsl:attribute name="codingScheme"><xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/></xsl:attribute>
			<xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="SenderRole">
		<xsl:element name="sender_MarketParticipant.marketRole.type">
			<xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="ReceiverIdentification">
		<xsl:element name="receiver_MarketParticipant.mRID">
			<xsl:attribute name="codingScheme"><xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/></xsl:attribute>
			<xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="ReceiverRole">
		<xsl:element name="receiver_MarketParticipant.marketRole.type">
			<xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="ScheduleTimeInterval">
		<xsl:element name="schedule_Period.timeInterval">
			<xsl:element name="start">
				<xsl:value-of select="substring(org:ScheduleTimeInterval/@v|ScheduleTimeInterval/@v,1,17)"/>
			</xsl:element>
			<xsl:element name="end">
				<xsl:value-of select="substring(org:ScheduleTimeInterval/@v|ScheduleTimeInterval/@v,19,17)"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!--   -->
	<xsl:template name="ConfirmedMessageIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ConfirmedMessageIdentification/@v|ConfirmedMessageIdentification/@v) &gt; 0 ">
				<xsl:element name="confirmed_MarketDocument.mRID">
					<xsl:value-of select="org:ConfirmedMessageIdentification/@v|ConfirmedMessageIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ConfirmedDocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ConfirmedDocumentIdentification/@v|ConfirmedDocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="confirmed_MarketDocument.mRID">
					<xsl:value-of select="org:ConfirmedDocumentIdentification/@v|ConfirmedDocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ConfirmedMessageVersion">
		<xsl:choose>
			<xsl:when test="count(org:ConfirmedMessageVersion/@v|ConfirmedMessageVersion/@v) &gt; 0 ">
				<xsl:element name="confirmed_MarketDocument.revisionNumber">
					<xsl:value-of select="org:ConfirmedMessageVersion/@v|ConfirmedMessageVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ConfirmedDocumentVersion">
		<xsl:choose>
			<xsl:when test="count(org:ConfirmedDocumentVersion/@v|ConfirmedDocumentVersion/@v) &gt; 0 ">
				<xsl:element name="confirmed_MarketDocument.revisionNumber">
					<xsl:value-of select="org:ConfirmedDocumentVersion/@v|ConfirmedDocumentVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Domain">
		<xsl:element name="domain.mRID">
			<xsl:choose>
				<xsl:when test="count(org:Domain/@codingScheme|Domain/@codingScheme) &gt; 0 ">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:Domain/@codingScheme|Domain/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:Domain/@v|Domain/@v"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="codingScheme"><xsl:value-of select="'A01'"/></xsl:attribute>
					<xsl:value-of select="'no domain'"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:element>
	</xsl:template>
	<xsl:template name="SubjectParty">
		<xsl:for-each select="org:SubjectParty|SubjectParty">
			<xsl:element name="subject_MarketParticipant.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="SubjectRole">
		<xsl:for-each select="org:SubjectRole|SubjectRole">
			<xsl:element name="subject_MarketParticipant.marketRole.type">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="ProcessType">
		<xsl:choose>
			<xsl:when test="count(org:ProcessType/@v|ProcessType/@v) &gt; 0 ">
				<xsl:element name="process.processType">
					<xsl:value-of select="org:ProcessType/@v|ProcessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ImposedTimeSeriesIdentification">
		<xsl:element name="mRID">
			<xsl:value-of select="org:ImposedTimeSeriesIdentification/@v|ImposedTimeSeriesIdentification/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="ImposedTimeSeriesVersion">
		<xsl:element name="version">
			<xsl:value-of select="org:ImposedTimeSeriesVersion/@v|ImposedTimeSeriesVersion/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="SendersTimeSeriesIdentification">
		<xsl:element name="mRID">
			<xsl:value-of select="org:SendersTimeSeriesIdentification/@v|SendersTimeSeriesIdentification/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="SendersTimeSeriesVersion">
		<xsl:element name="version">
			<xsl:value-of select="org:SendersTimeSeriesVersion/@v|SendersTimeSeriesVersion/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="BusinessType">
		<xsl:element name="businessType">
			<xsl:value-of select="org:BusinessType/@v|BusinessType/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="Product">
		<xsl:element name="product">
			<xsl:value-of select="org:Product/@v|Product/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="ObjectAggregation">
		<xsl:element name="objectAggregation">
			<xsl:value-of select="org:ObjectAggregation/@v|ObjectAggregation/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="InArea">
		<xsl:for-each select="org:InArea|InArea">
			<xsl:element name="in_Domain.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="OutArea">
		<xsl:for-each select="org:OutArea|OutArea">
			<xsl:element name="out_Domain.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="MeteringPointIdentification">
		<xsl:for-each select="org:MeteringPointIdentification|MeteringPointIdentification">
			<xsl:element name="marketEvaluationPoint.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="InParty">
		<xsl:for-each select="org:InParty|InParty">
			<xsl:element name="in_MarketParticipant.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="OutParty">
		<xsl:for-each select="org:OutParty|OutParty">
			<xsl:element name="out_MarketParticipant.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="CapacityContractType">
		<xsl:for-each select="org:CapacityContractType|CapacityContractType">
			<xsl:element name="marketAgreement.type">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="CapacityAgreementIdentification">
		<xsl:for-each select="org:CapacityAgreementIdentification|CapacityAgreementIdentification">
			<xsl:element name="marketAgreement.mRID">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="MeasurementUnit">
		<xsl:element name="measure_Unit.name">
			<xsl:value-of select="org:MeasurementUnit/@v|MeasurementUnit/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="CurveType">
		<xsl:choose>
			<xsl:when test="count(org:CurveType/@v|CurveType/@v) &gt; 0 ">
				<xsl:element name="curveType">
					<xsl:value-of select="org:CurveType/@v|CurveType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReasonCode">
		<xsl:element name="code">
			<xsl:value-of select="org:ReasonCode/@v|ReasonCode/@v"/>
		</xsl:element>
		<xsl:for-each select="org:ReasonText|ReasonText">
			<xsl:element name="text">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="TimeInterval">
		<xsl:element name="timeInterval">
			<xsl:element name="start">
				<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,1,17)"/>
			</xsl:element>
			<xsl:element name="end">
				<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,19,17)"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="Resolution">
		<xsl:element name="resolution">
			<xsl:value-of select="org:Resolution/@v|Resolution/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="Pos">
		<xsl:element name="position">
			<xsl:value-of select="org:Pos/@v|Pos/@v"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="Qty">
		<xsl:element name="quantity">
			<xsl:value-of select="org:Qty/@v|Qty/@v"/>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>
