<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:ecan:auctionspecificationdocument:6:0" xmlns="urn:iec62325.351:tc57wg16:451-3:capacityspecificationdocument:7:1" version="1.0" exclude-result-prefixes="org">
	<xsl:output method="xml"/>
	<!--This xsl convert an ENTSO-E auction specification document version 4, 5 or 6 to a CIM auction specification  document version 7 -->
	<xsl:template match="org:CapacityAuctionSpecificationDocument|CapacityAuctionSpecificationDocument">
		<CapacityAuctionSpecification_MarketDocument>
			<xsl:call-template name="DocumentIdentification"/>
			<xsl:call-template name="DocumentVersion"/>
			<xsl:call-template name="DocumentType"/>
			<xsl:call-template name="ProcessType"/>
			<xsl:call-template name="SenderIdentification"/>
			<xsl:call-template name="SenderRole"/>

			<xsl:call-template name="ReceiverIdentification"/>
			<xsl:call-template name="ReceiverRole"/>
			
			<xsl:call-template name="CreationDateTime"/>
			<xsl:call-template name="DocumentTimeInterval"/>
			<xsl:call-template name="Domain"/>
			
			<xsl:call-template name="AuctionTimeSeries"/>
			
		</CapacityAuctionSpecification_MarketDocument>
	</xsl:template>
	
	<xsl:template name="AuctionTimeSeries">
		<xsl:for-each select="org:AuctionTimeSeries|AuctionTimeSeries">
			<xsl:element name="Auction_TimeSeries">
				<xsl:call-template name="AuctionIdentification"/>
				<xsl:call-template name="BusinessType"/>
				<xsl:call-template name="ClassificationCategory"/>
				<xsl:call-template name="AuctionType"/>
				<xsl:call-template name="AllocationMode"/>
				<xsl:call-template name="PaymentTerms"/>
				
				<xsl:call-template name="Cancelled"/>
				
				<xsl:call-template name="BiddingPeriod"/>
				<xsl:call-template name="InArea"/>
				<xsl:call-template name="OutArea"/>
				<xsl:call-template name="ContractType"/>
				<xsl:call-template name="DeliveryPeriod"/>
				<xsl:call-template name="MeasureUnitQuantity"/>
				<xsl:call-template name="MeasureUnitPrice"/>
				<xsl:call-template name="Currency"/>
				<xsl:call-template name="NotificationDateTime"/>
				<xsl:call-template name="ContestationEndDateTime"/>
				<xsl:call-template name="PublicationDateTime"/>

				<xsl:call-template name="ResaleLimitDateTime"/>
				<xsl:call-template name="CurveType"/>
				
				<xsl:call-template name="ConnectingLine"/>
				
				<xsl:call-template name="Period"/>
				
				<xsl:call-template name="AuctionDescription"/>
				
				<xsl:call-template name="RightsCharacteristics"/>
				
				<xsl:call-template name="Reason"/>
				
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Period">
		<xsl:for-each select="org:Period|Period">
			<xsl:element name="Period">
			
				<xsl:call-template name="TimeInterval"/>
				<xsl:call-template name="Resolution"/>
				<xsl:call-template name="Interval"/>
				
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Interval">
		<xsl:for-each select="org:Interval|Interval">
			<xsl:element name="Point">
				<xsl:call-template name="Pos"/>
				<xsl:call-template name="Qty"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="AuctionDescription">
		<xsl:for-each select="org:AuctionDescription|AuctionDescription">
			<xsl:element name="AuctionDescription_AttributeInstanceComponent">
				<xsl:call-template name="LineNo"/>
				<xsl:call-template name="LineText"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="RightsCharacteristics">
		<xsl:for-each select="org:RightsCharacteristics|RightsCharacteristics">
			<xsl:element name="RightsCharacteristics_Auction">
				<xsl:call-template name="RightsType"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Reason">
		<xsl:for-each select="org:Reason|Reason">
			<xsl:element name="Reason">
				<xsl:call-template name="ReasonCode"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="DocumentIdentification">
		<xsl:choose>
				<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
					<xsl:element name="mRID">
				        <xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
			        </xsl:element>
				</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="DocumentVersion">
		<xsl:choose>
				<xsl:when test="count(org:DocumentVersion/@v|DocumentVersion/@v) &gt; 0 ">
					<xsl:element name="revisionNumber">
				        <xsl:value-of select="org:DocumentVersion/@v|DocumentVersion/@v"/>
			        </xsl:element>
				</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="DocumentType">
		<xsl:choose>
			<xsl:when test="count(org:DocumentType/@v|DocumentType/@v) &gt; 0 ">
				<xsl:element name="type">
			        <xsl:value-of select="org:DocumentType/@v|DocumentType/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ProcessType">
		<xsl:choose>
			<xsl:when test="count(org:ProcessType/@v|ProcessType/@v) &gt; 0 ">
				<xsl:element name="process.processType">
			        <xsl:value-of select="org:ProcessType/@v|ProcessType/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="AuctionType">
		<xsl:choose>
			<xsl:when test="count(org:AuctionType/@v|AuctionType/@v) &gt; 0 ">
				<xsl:element name="auction.type">
			        <xsl:value-of select="org:AuctionType/@v|AuctionType/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="BiddingPeriod">
		<xsl:choose>
			<xsl:when test="count(org:BiddingPeriod/@v|BiddingPeriod/@v) &gt; 0 ">
				<xsl:element name="bidding_Period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:BiddingPeriod/@v|BiddingPeriod/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:BiddingPeriod/@v|BiddingPeriod/@v,19,17)"/>
					</xsl:element>
				</xsl:element>		
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ContractType">
		<xsl:choose>
			<xsl:when test="count(org:ContractType/@v|ContractType/@v) &gt; 0 ">
				<xsl:element name="marketAgreement.type">
			        <xsl:value-of select="org:ContractType/@v|ContractType/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="DeliveryPeriod">
		<xsl:choose>
			<xsl:when test="count(org:DeliveryPeriod/@v|DeliveryPeriod/@v) &gt; 0 ">
				<xsl:element name="delivery_Period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:DeliveryPeriod/@v|DeliveryPeriod/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:DeliveryPeriod/@v|DeliveryPeriod/@v,19,17)"/>
					</xsl:element>
				</xsl:element>		
			</xsl:when>
		</xsl:choose>	
	</xsl:template>
	
	<xsl:template name="MeasureUnitQuantity">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnitQuantity/@v|MeasureUnitQuantity/@v) &gt; 0 ">
				<xsl:element name="quantity_Measure_Unit.name">
			        <xsl:value-of select="org:MeasureUnitQuantity/@v|MeasureUnitQuantity/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="MeasureUnitPrice">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnitPrice/@v|MeasureUnitPrice/@v) &gt; 0 ">
				<xsl:element name="price_Measure_Unit.name">
			        <xsl:value-of select="org:MeasureUnitPrice/@v|MeasureUnitPrice/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="Currency">
		<xsl:choose>
			<xsl:when test="count(org:Currency/@v|Currency/@v) &gt; 0 ">
				<xsl:element name="currency_Unit.name">
			        <xsl:value-of select="org:Currency/@v|Currency/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="PaymentTerms">
		<xsl:choose>
			<xsl:when test="count(org:PaymentTerms/@v|PaymentTerms/@v) &gt; 0 ">
				<xsl:element name="auction.paymentTerms">
			        <xsl:value-of select="org:PaymentTerms/@v|PaymentTerms/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="NotificationDateTime">
		<xsl:choose>
			<xsl:when test="count(org:NotificationDateTime/@v|NotificationDateTime/@v) &gt; 0 ">
				<xsl:element name="notification_MarketAgreement.createdDateTime">
			        <xsl:value-of select="org:NotificationDateTime/@v|NotificationDateTime/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ContestationEndDateTime">
		<xsl:choose>
			<xsl:when test="count(org:ContestationEndDateTime/@v|ContestationEndDateTime/@v) &gt; 0 ">
				<xsl:element name="contestation_MarketAgreement.createdDateTime">
			        <xsl:value-of select="org:ContestationEndDateTime/@v|ContestationEndDateTime/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="PublicationDateTime">
		<xsl:choose>
			<xsl:when test="count(org:PublicationDateTime/@v|PublicationDateTime/@v) &gt; 0 ">
				<xsl:element name="publication_MarketAgreement.createdDateTime">
			        <xsl:value-of select="org:PublicationDateTime/@v|PublicationDateTime/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="ResaleLimitDateTime">
		<xsl:choose>
			<xsl:when test="count(org:ResaleLimitDateTime/@v|ResaleLimitDateTime/@v) &gt; 0 ">
				<xsl:element name="resale_MarketAgreement.createdDateTime">
			        <xsl:value-of select="org:ResaleLimitDateTime/@v|ResaleLimitDateTime/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="AllocationMode">
		<xsl:choose>
			<xsl:when test="count(org:AllocationMode/@v|AllocationMode/@v) &gt; 0 ">
				<xsl:element name="auction.allocationMode">
			        <xsl:value-of select="org:AllocationMode/@v|AllocationMode/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="SenderIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SenderIdentification/@v|SenderIdentification/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/>
					</xsl:attribute>
			        <xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
			    </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="SenderRole">
		<xsl:choose>
			<xsl:when test="count(org:SenderRole/@v|SenderRole/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.marketRole.type">
			        <xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="ReceiverIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverIdentification/@v|ReceiverIdentification/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/>
					</xsl:attribute>
			        <xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
			    </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ReceiverRole">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverRole/@v|ReceiverRole/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.marketRole.type">
			        <xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="CreationDateTime">
		<xsl:choose>
			<xsl:when test="count(org:CreationDateTime/@v|CreationDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
			        <xsl:value-of select="org:CreationDateTime/@v|CreationDateTime/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="DocumentTimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:DocumentTimeInterval/@v|DocumentTimeInterval/@v) &gt; 0 ">
				<xsl:element name="period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:DocumentTimeInterval/@v|DocumentTimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:DocumentTimeInterval/@v|DocumentTimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>		
			</xsl:when>
		</xsl:choose>	
	</xsl:template>
	<xsl:template name="Domain">
		<xsl:element name="domain.mRID">
		<xsl:choose>
				<xsl:when test="count(org:Domain/@codingScheme|Domain/@codingScheme) &gt; 0 ">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:Domain/@codingScheme|Domain/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:Domain/@v|Domain/@v"/>
				</xsl:when>
		</xsl:choose>
		</xsl:element>
	</xsl:template>
	
	<xsl:template name="SubjectParty">
		<xsl:for-each select="org:SubjectParty|SubjectParty">
			<xsl:element name="subject_MarketParticipant.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="SubjectRole">
		<xsl:for-each select="org:SubjectRole|SubjectRole">
			<xsl:element name="subject_MarketParticipant.marketRole.type">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="MatchingPeriod">
		<xsl:for-each select="org:MatchingPeriod|MatchingPeriod">
			<xsl:element name="matching_Time_Period.timeInterval">
				<xsl:element name="start">
					<xsl:value-of select="substring(@v,1,17)"/>
				</xsl:element>
				<xsl:element name="end">
					<xsl:value-of select="substring(@v,19,17)"/>
				</xsl:element>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="TimeSeriesIdentification">
		<xsl:choose>
			<xsl:when test="count(org:TimeSeriesIdentification/@v|TimeSeriesIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
			        <xsl:value-of select="org:TimeSeriesIdentification/@v|TimeSeriesIdentification/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="SendersTimeSeriesVersion">
		<xsl:choose>
			<xsl:when test="count(org:SendersTimeSeriesVersion/@v|SendersTimeSeriesVersion/@v) &gt; 0 ">
				<xsl:element name="version">
			        <xsl:value-of select="org:SendersTimeSeriesVersion/@v|SendersTimeSeriesVersion/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="BusinessType">
		<xsl:choose>
			<xsl:when test="count(org:BusinessType/@v|BusinessType/@v) &gt; 0 ">
				<xsl:element name="businessType">
			        <xsl:value-of select="org:BusinessType/@v|BusinessType/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="Product">
		<xsl:choose>
			<xsl:when test="count(org:Product/@v|Product/@v) &gt; 0 ">
				<xsl:element name="product">
			        <xsl:value-of select="org:Product/@v|Product/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="ObjectAggregation">
		<xsl:choose>
			<xsl:when test="count(org:ObjectAggregation/@v|ObjectAggregation/@v) &gt; 0 ">
				<xsl:element name="objectAggregation">
			        <xsl:value-of select="org:ObjectAggregation/@v|ObjectAggregation/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="InArea">
		<xsl:for-each select="org:InArea|InArea">
			<xsl:element name="in_Domain.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="OutArea">
		<xsl:for-each select="org:OutArea|OutArea">
			<xsl:element name="out_Domain.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="MeteringPointIdentification">
		<xsl:for-each select="org:MeteringPointIdentification|MeteringPointIdentification">
			<xsl:element name="marketEvaluationPoint.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="InParty">
		<xsl:for-each select="org:InParty|InParty">
			<xsl:element name="in_MarketParticipant.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="OutParty">
		<xsl:for-each select="org:OutParty|OutParty">
			<xsl:element name="out_MarketParticipant.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="ClassificationCategory">
		<xsl:choose>
			<xsl:when test="count(org:ClassificationCategory/@v|ClassificationCategory/@v) &gt; 0 ">
				<xsl:element name="auction.category">
					<xsl:value-of select="org:ClassificationCategory/@v|ClassificationCategory/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	 
	<xsl:template name="AuctionIdentification">
		<xsl:choose>
			<xsl:when test="count(org:AuctionIdentification/@v|AuctionIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
			        <xsl:value-of select="org:AuctionIdentification/@v|AuctionIdentification/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="MeasureUnit">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnit/@v|MeasureUnit/@v) &gt; 0 ">
				<xsl:element name="measure_Unit.name">
			        <xsl:value-of select="org:MeasureUnit/@v|MeasureUnit/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
<!-- ReasonCode -->	
	<xsl:template name="ReasonCode">
		<xsl:element name="code">
			<xsl:value-of select="org:Reasoncode/@v|Reasoncode/@v"/>
		</xsl:element>
		<xsl:for-each select="org:ReasonText|ReasonText">
			<xsl:element name="text">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="TimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:TimeInterval/@v|TimeInterval/@v) &gt; 0 ">
				<xsl:element name="timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>		
			</xsl:when>
		</xsl:choose>	
	</xsl:template>
	
	<xsl:template name="Resolution">
		<xsl:choose>
			<xsl:when test="count(org:Resolution/@v|Resolution/@v) &gt; 0 ">
				<xsl:element name="resolution">
			        <xsl:value-of select="org:Resolution/@v|Resolution/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="Pos">
		<xsl:choose>
			<xsl:when test="count(org:Pos/@v|Pos/@v) &gt; 0 ">
				<xsl:element name="position">
			        <xsl:value-of select="org:Pos/@v|Pos/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="Qty">
		<xsl:choose>
			<xsl:when test="count(org:Qty/@v|Qty/@v) &gt; 0 ">
				<xsl:element name="quantity">
			        <xsl:value-of select="org:Qty/@v|Qty/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="LineNo">
		<xsl:choose>
			<xsl:when test="count(org:LineNo/@v|LineNo/@v) &gt; 0 ">
				<xsl:element name="position">
			        <xsl:value-of select="org:LineNo/@v|LineNo/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>	

	<xsl:template name="LineText">
		<xsl:choose>
			<xsl:when test="count(org:LineText/@v|LineText/@v) &gt; 0 ">
				<xsl:element name="attribute">
			        <xsl:value-of select="org:LineText/@v|LineText/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>	
	
	<xsl:template name="CurveType">
		<xsl:choose>
			<xsl:when test="count(org:CurveType/@v|CurveType/@v) &gt; 0 ">
				<xsl:element name="curveType">
			        <xsl:value-of select="org:CurveType/@v|CurveType/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
		
	<xsl:template name="Cancelled">
		<xsl:choose>
			<xsl:when test="count(org:Cancelled/@v|Cancelled/@v) &gt; 0 ">
				<xsl:element name="auction.cancelled">
			        <xsl:value-of select="org:Cancelled/@v|Cancelled/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
		
	<xsl:template name="ConnectingLine">
		<xsl:for-each select="org:ConnectingLine|ConnectingLine">
			<xsl:element name="connectingLine_RegisteredResource.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="RightsType">
		<xsl:choose>
			<xsl:when test="count(org:RightsType/@v|RightsType/@v) &gt; 0 ">
				<xsl:element name="rights">
			        <xsl:value-of select="org:RightsType/@v|RightsType/@v"/>
			       </xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
		
</xsl:stylesheet>
