<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:ecan:biddocument:6:0" xmlns="urn:iec62325.351:tc57wg16:451-3:biddocument:7:0" version="1.0" exclude-result-prefixes="org">
	<xsl:output method="xml"/>
	<!--This xsl convert an ENTSO-E bid document version 4, 5 or 6 to a CIM bid document version 7 -->
	<xsl:template match="org:BidDocument|BidDocument">
		<Bid_MarketDocument>
			<xsl:call-template name="DocumentIdentification"/>
			<xsl:call-template name="DocumentVersion"/>
			<xsl:call-template name="DocumentType"/>
			<xsl:call-template name="SenderIdentification"/>
			<xsl:call-template name="SenderRole"/>
			<xsl:call-template name="ReceiverIdentification"/>
			<xsl:call-template name="ReceiverRole"/>
			<xsl:call-template name="CreationDateTime"/>
			<xsl:call-template name="BidTimeInterval"/>
			<xsl:call-template name="Domain"/>
			<xsl:call-template name="SubjectParty"/>
			<xsl:call-template name="SubjectRole"/>
			<xsl:call-template name="BidTimeSeries"/>
		</Bid_MarketDocument>
	</xsl:template>
	<xsl:template name="BidTimeSeries">
		<xsl:for-each select="org:BidTimeSeries|BidTimeSeries">
			<xsl:element name="Bid_TimeSeries">
				<xsl:call-template name="BidIdentification"/>
				<xsl:call-template name="AuctionIdentification"/>				
				<xsl:call-template name="BusinessType"/>
				<xsl:call-template name="InArea"/>
				<xsl:call-template name="OutArea"/>
				<xsl:call-template name="MeasureUnitQuantity"/>
				<xsl:call-template name="Currency"/>
				<xsl:call-template name="MeasureUnitPrice"/>
				<xsl:call-template name="Divisible"/>
				<xsl:call-template name="LinkedBidsIdentification"/>
				<xsl:call-template name="BlockBid"/>
				<xsl:call-template name="Period"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Period">
		<xsl:for-each select="org:Period|Period">
			<xsl:element name="Period">
				<xsl:call-template name="TimeInterval"/>
				<xsl:call-template name="Resolution"/>
				<xsl:call-template name="Interval"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Interval">
		<xsl:for-each select="org:Interval|Interval">
			<xsl:element name="Point">
				<xsl:call-template name="Pos"/>
				<xsl:call-template name="Qty"/>
				<xsl:call-template name="PriceAmount"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Reason">
		<xsl:for-each select="org:Reason|Reason">
			<xsl:element name="Reason">
				<xsl:call-template name="ReasonCode"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	
<!-- Entities Information -->	
<!-- DocumentIdentification -->		
	<xsl:template name="DocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- DocumentVersion -->		
	<xsl:template name="DocumentVersion">
		<xsl:choose>
			<xsl:when test="count(org:DocumentVersion/@v|DocumentVersion/@v) &gt; 0 ">
				<xsl:element name="revisionNumber">
					<xsl:value-of select="org:DocumentVersion/@v|DocumentVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- DocumentType -->	
	<xsl:template name="DocumentType">
		<xsl:choose>
			<xsl:when test="count(org:DocumentType/@v|DocumentType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:DocumentType/@v|DocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- ProcessType -->		<!-- NOT USED -->
	<xsl:template name="ProcessType">
		<xsl:choose>
			<xsl:when test="count(org:ProcessType/@v|ProcessType/@v) &gt; 0 ">
				<xsl:element name="process.processType">
					<xsl:value-of select="org:ProcessType/@v|ProcessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- SenderIdentification -->		
	<xsl:template name="SenderIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SenderIdentification/@v|SenderIdentification/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- SenderRole -->	
	<xsl:template name="SenderRole">
		<xsl:choose>
			<xsl:when test="count(org:SenderRole/@v|SenderRole/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- ReceiverIdentification -->		
	<xsl:template name="ReceiverIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverIdentification/@v|ReceiverIdentification/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- ReceiverRole -->		
	<xsl:template name="ReceiverRole">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverRole/@v|ReceiverRole/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- CreationDateTime -->	
	<xsl:template name="CreationDateTime">
		<xsl:choose>
			<xsl:when test="count(org:CreationDateTime/@v|CreationDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:CreationDateTime/@v|CreationDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- CapacityTimeInterval -->			
	<xsl:template name="CapacityTimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:CapacityTimeInterval/@v|CapacityTimeInterval/@v) &gt; 0 ">
				<xsl:element name="period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:CapacityTimeInterval/@v|CapacityTimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:CapacityTimeInterval/@v|CapacityTimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- BidTimeInterval -->			
	<xsl:template name="BidTimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:BidTimeInterval/@v|BidTimeInterval/@v) &gt; 0 ">
				<xsl:element name="period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:BidTimeInterval/@v|BidTimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:BidTimeInterval/@v|BidTimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- Domain -->	
	<xsl:template name="Domain">
		<xsl:element name="domain.mRID">
		<xsl:choose>
				<xsl:when test="count(org:Domain/@codingScheme|Domain/@codingScheme) &gt; 0 ">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:Domain/@codingScheme|Domain/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:Domain/@v|Domain/@v"/>
				</xsl:when>
		</xsl:choose>
		</xsl:element>
	</xsl:template>
<!-- -->
<!-- SubjectParty -->		
	<xsl:template name="SubjectParty">
		<xsl:choose>
			<xsl:when test="count(org:SubjectParty/@v|SubjectParty/@v) &gt; 0 ">
				<xsl:element name="subject_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:SubjectParty/@codingScheme|SubjectParty/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:SubjectParty/@v|SubjectParty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- SubjectRole -->		
	<xsl:template name="SubjectRole">
		<xsl:choose>
			<xsl:when test="count(org:SubjectRole/@v|SubjectRole/@v) &gt; 0 ">
				<xsl:element name="subject_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SubjectRole/@v|SubjectRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- MatchingPeriod -->
	<xsl:template name="MatchingPeriod">
		<xsl:for-each select="org:MatchingPeriod|MatchingPeriod">
			<xsl:element name="matching_Time_Period.timeInterval">
				<xsl:element name="start">
					<xsl:value-of select="substring(@v,1,17)"/>
				</xsl:element>
				<xsl:element name="end">
					<xsl:value-of select="substring(@v,19,17)"/>
				</xsl:element>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
<!-- -->
<!-- TimeSeriesIdentification -->
	<xsl:template name="TimeSeriesIdentification">
		<xsl:choose>
			<xsl:when test="count(org:TimeSeriesIdentification/@v|TimeSeriesIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:TimeSeriesIdentification/@v|TimeSeriesIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- BidIdentification -->
	<xsl:template name="BidIdentification">
		<xsl:choose>
			<xsl:when test="count(org:BidIdentification/@v|BidIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:BidIdentification/@v|BidIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>	
<!-- -->
<!-- AuctionIdentification -->	
	<xsl:template name="AuctionIdentification">
		<xsl:choose>
			<xsl:when test="count(org:AuctionIdentification/@v|AuctionIdentification/@v) &gt; 0 ">
				<xsl:element name="auction.mRID">
					<xsl:value-of select="org:AuctionIdentification/@v|AuctionIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>	
<!-- -->
<!-- SendersTimeSeriesVersion -->	
	<xsl:template name="SendersTimeSeriesVersion">
		<xsl:choose>
			<xsl:when test="count(org:SendersTimeSeriesVersion/@v|SendersTimeSeriesVersion/@v) &gt; 0 ">
				<xsl:element name="version">
					<xsl:value-of select="org:SendersTimeSeriesVersion/@v|SendersTimeSeriesVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- BusinessType -->	
	<xsl:template name="BusinessType">
		<xsl:choose>
			<xsl:when test="count(org:BusinessType/@v|BusinessType/@v) &gt; 0 ">
				<xsl:element name="businessType">
					<xsl:value-of select="org:BusinessType/@v|BusinessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- Product -->	
	<xsl:template name="Product">
		<xsl:choose>
			<xsl:when test="count(org:Product/@v|Product/@v) &gt; 0 ">
				<xsl:element name="product">
					<xsl:value-of select="org:Product/@v|Product/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- ObjectAggregation -->
	<xsl:template name="ObjectAggregation">
		<xsl:choose>
			<xsl:when test="count(org:ObjectAggregation/@v|ObjectAggregation/@v) &gt; 0 ">
				<xsl:element name="objectAggregation">
					<xsl:value-of select="org:ObjectAggregation/@v|ObjectAggregation/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- InArea -->
	<xsl:template name="InArea">
		<xsl:choose>
			<xsl:when test="count(org:InArea/@v|InArea/@v) &gt; 0 ">
				<xsl:element name="in_Domain.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:InArea/@codingScheme|InArea/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:InArea/@v|InArea/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- OutArea -->
	<xsl:template name="OutArea">
		<xsl:choose>
			<xsl:when test="count(org:InArea/@v|OutArea/@v) &gt; 0 ">
				<xsl:element name="out_Domain.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:OutArea/@codingScheme|OutArea/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:OutArea/@v|OutArea/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- MeasureUnitQuantity -->	
	<xsl:template name="MeasureUnitQuantity">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnitQuantity/@v|MeasureUnitQuantity/@v) &gt; 0 ">
				<xsl:element name="quantity_Measure_Unit.name">
					<xsl:value-of select="org:MeasureUnitQuantity/@v|MeasureUnitQuantity/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>	
<!-- -->
<!-- Currency -->	
	<xsl:template name="Currency">
		<xsl:choose>
			<xsl:when test="count(org:Currency/@v|Currency/@v) &gt; 0 ">
				<xsl:element name="currency_Unit.name">
					<xsl:value-of select="org:Currency/@v|Currency/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>		
<!-- -->
<!-- MeasureUnitPrice -->	
	<xsl:template name="MeasureUnitPrice">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnitPrice/@v|MeasureUnitPrice/@v) &gt; 0 ">
				<xsl:element name="price_Measure_Unit.name">
					<xsl:value-of select="org:MeasureUnitPrice/@v|MeasureUnitPrice/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>		
<!-- -->
<!-- Divisible -->	
	<xsl:template name="Divisible">
		<xsl:choose>
			<xsl:when test="count(org:Divisible/@v|Divisible/@v) &gt; 0 ">
				<xsl:element name="divisible">
					<xsl:value-of select="org:Divisible/@v|Divisible/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>	
<!-- -->
<!-- LinkedBidsIdentification -->	
	<xsl:template name="LinkedBidsIdentification">
		<xsl:choose>
			<xsl:when test="count(org:LinkedBidsIdentification/@v|LinkedBidsIdentification/@v) &gt; 0 ">
				<xsl:element name="linkedBidsIdentification">
					<xsl:value-of select="org:LinkedBidsIdentification/@v|LinkedBidsIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>		
<!-- -->
<!-- BlockBid -->	
	<xsl:template name="BlockBid">
		<xsl:choose>
			<xsl:when test="count(org:BlockBid/@v|BlockBid/@v) &gt; 0 ">
				<xsl:element name="blockBid">
					<xsl:value-of select="org:BlockBid/@v|BlockBid/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>		
<!-- -->
<!-- MeteringPointIdentification -->	
	<xsl:template name="MeteringPointIdentification">
		<xsl:choose>
			<xsl:when test="count(org:MeteringPointIdentification/@v|MeteringPointIdentification/@v) &gt; 0 ">
				<xsl:element name="marketEvaluationPoint.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:MeteringPointIdentification/@codingScheme|MeteringPointIdentification/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:MeteringPointIdentification/@v|MeteringPointIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- InParty -->	
	<xsl:template name="InParty">
		<xsl:choose>
			<xsl:when test="count(org:InParty/@v|InParty/@v) &gt; 0 ">
				<xsl:element name="in_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:InParty/@codingScheme|InParty/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:InParty/@v|InParty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- OutParty -->	
	<xsl:template name="OutParty">
		<xsl:choose>
			<xsl:when test="count(org:OutParty/@v|OutParty/@v) &gt; 0 ">
				<xsl:element name="out_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:OutParty/@codingScheme|OutParty/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:OutParty/@v|OutParty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- ClassificationCategory -->	
	<xsl:template name="ClassificationCategory">
		<xsl:choose>
			<xsl:when test="count(org:ClassificationCategory/@v|ClassificationCategory/@v) &gt; 0 ">
				<xsl:element name="auction.category">
					<xsl:value-of select="org:ClassificationCategory/@v|ClassificationCategory/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- MeasureUnit -->	
	<xsl:template name="MeasureUnit">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnit/@v|MeasureUnit/@v) &gt; 0 ">
				<xsl:element name="measure_Unit.name">
					<xsl:value-of select="org:MeasureUnit/@v|MeasureUnit/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- ReasonCode -->	
	<xsl:template name="ReasonCode">
		<xsl:element name="code">
			<xsl:value-of select="org:ReasonCode/@v|ReasonCode/@v"/>
		</xsl:element>
		<xsl:for-each select="org:ReasonText|ReasonText">
			<xsl:element name="text">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
<!-- -->
<!-- TimeInterval -->	
	<xsl:template name="TimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:TimeInterval/@v|TimeInterval/@v) &gt; 0 ">
				<xsl:element name="timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- Resolution -->	
	<xsl:template name="Resolution">
		<xsl:choose>
			<xsl:when test="count(org:Resolution/@v|Resolution/@v) &gt; 0 ">
				<xsl:element name="resolution">
					<xsl:value-of select="org:Resolution/@v|Resolution/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- Pos -->	
	<xsl:template name="Pos">
		<xsl:choose>
			<xsl:when test="count(org:Pos/@v|Pos/@v) &gt; 0 ">
				<xsl:element name="position">
					<xsl:value-of select="org:Pos/@v|Pos/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- Qty -->	
	<xsl:template name="Qty">
		<xsl:choose>
			<xsl:when test="count(org:Qty/@v|Qty/@v) &gt; 0 ">
				<xsl:element name="quantity">
					<xsl:value-of select="org:Qty/@v|Qty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
<!-- PriceAmount -->	
	<xsl:template name="PriceAmount">
		<xsl:choose>
			<xsl:when test="count(org:PriceAmount/@v|PriceAmount/@v) &gt; 0 ">
				<xsl:element name="price.amount">
					<xsl:value-of select="org:PriceAmount/@v|PriceAmount/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
<!-- CurveType -->	
	<xsl:template name="CurveType">
		<xsl:choose>
			<xsl:when test="count(org:CurveType/@v|CurveType/@v) &gt; 0 ">
				<xsl:element name="curveType">
					<xsl:value-of select="org:CurveType/@v|CurveType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	
</xsl:stylesheet>
