<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:ecan:capacitydocument:6:0" xmlns="urn:iec62325.351:tc57wg16:451-3:capacitydocument:7:1" version="1.0"  exclude-result-prefixes="org">
	<xsl:output method="xml"/>
	<!-- This xsl convert an ENTSO-E capacity document version 4, 5 or 6 to a CIM capacity document version 7 -->
	<xsl:template match="org:CapacityDocument|CapacityDocument">
		<Capacity_MarketDocument>
			<xsl:call-template name="DocumentIdentification"/>
			<xsl:call-template name="DocumentVersion"/>
			<xsl:call-template name="DocumentType"/>
			<xsl:call-template name="ProcessType"/>
			<xsl:call-template name="SenderIdentification"/>
			<xsl:call-template name="SenderRole"/>
			<xsl:call-template name="ReceiverIdentification"/>
			<xsl:call-template name="ReceiverRole"/>
			<xsl:call-template name="CreationDateTime"/>
			<xsl:call-template name="CapacityTimeInterval"/>
			<xsl:call-template name="Domain"/>
			<xsl:call-template name="CapacityTimeSeries"/>
			<xsl:call-template name="Reason"/>
		</Capacity_MarketDocument>
	</xsl:template>
	<xsl:template name="CapacityTimeSeries">
		<xsl:for-each select="org:CapacityTimeSeries|CapacityTimeSeries">
			<xsl:element name="TimeSeries">
				<xsl:call-template name="TimeSeriesIdentification"/>
				<xsl:call-template name="BusinessType"/>
				<xsl:call-template name="Product"/>
				<xsl:call-template name="InArea"/>
				<xsl:call-template name="OutArea"/>
				<xsl:call-template name="MeasureUnit"/>
				<xsl:call-template name="AuctionIdentification"/>
				<xsl:call-template name="ClassificationCategory"/>
				<xsl:call-template name="CurveType"/>
				<xsl:call-template name="ConnectingLine"/>
				<xsl:call-template name="Period"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Period">
		<xsl:for-each select="org:Period|Period">
			<xsl:element name="Period">
				<xsl:call-template name="TimeInterval"/>
				<xsl:call-template name="Resolution"/>
				<xsl:call-template name="Interval"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Interval">
		<xsl:for-each select="org:Interval|Interval">
			<xsl:element name="Point">
				<xsl:call-template name="Pos"/>
				<xsl:call-template name="Qty"/>
				<xsl:call-template name="Reason"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Reason">
		<xsl:for-each select="org:Reason|Reason">
			<xsl:element name="Reason">
				<xsl:call-template name="ReasonCode"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="DocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DocumentVersion">
		<xsl:choose>
			<xsl:when test="count(org:DocumentVersion/@v|DocumentVersion/@v) &gt; 0 ">
				<xsl:element name="revisionNumber">
					<xsl:value-of select="org:DocumentVersion/@v|DocumentVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DocumentType">
		<xsl:choose>
			<xsl:when test="count(org:DocumentType/@v|DocumentType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:DocumentType/@v|DocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ProcessType">
		<xsl:choose>
			<xsl:when test="count(org:ProcessType/@v|ProcessType/@v) &gt; 0 ">
				<xsl:element name="process.processType">
					<xsl:value-of select="org:ProcessType/@v|ProcessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SenderIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SenderIdentification/@v|SenderIdentification/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="SenderRole">
		<xsl:choose>
			<xsl:when test="count(org:SenderRole/@v|SenderRole/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceiverIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverIdentification/@v|ReceiverIdentification/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceiverRole">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverRole/@v|ReceiverRole/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="CreationDateTime">
		<xsl:choose>
			<xsl:when test="count(org:CreationDateTime/@v|CreationDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:CreationDateTime/@v|CreationDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="CapacityTimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:CapacityTimeInterval/@v|CapacityTimeInterval/@v) &gt; 0 ">
				<xsl:element name="period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:CapacityTimeInterval/@v|CapacityTimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:CapacityTimeInterval/@v|CapacityTimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Domain">
		<xsl:element name="domain.mRID">
		<xsl:choose>
				<xsl:when test="count(org:Domain/@codingScheme|Domain/@codingScheme) &gt; 0 ">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:Domain/@codingScheme|Domain/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:Domain/@v|Domain/@v"/>
				</xsl:when>
		</xsl:choose>
		</xsl:element>
	</xsl:template>
	<!-- Time Series -->
	<xsl:template name="TimeSeriesIdentification">
		<xsl:choose>
			<xsl:when test="count(org:TimeSeriesIdentification/@v|TimeSeriesIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:TimeSeriesIdentification/@v|TimeSeriesIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="BusinessType">
		<xsl:choose>
			<xsl:when test="count(org:BusinessType/@v|BusinessType/@v) &gt; 0 ">
				<xsl:element name="businessType">
					<xsl:value-of select="org:BusinessType/@v|BusinessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Product">
		<xsl:choose>
			<xsl:when test="count(org:Product/@v|Product/@v) &gt; 0 ">
				<xsl:element name="product">
					<xsl:value-of select="org:Product/@v|Product/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="InArea">
		<xsl:choose>
			<xsl:when test="count(org:InArea/@v|InArea/@v) &gt; 0 ">
				<xsl:element name="in_Domain.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:InArea/@codingScheme|InArea/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:InArea/@v|InArea/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="OutArea">
		<xsl:choose>
			<xsl:when test="count(org:InArea/@v|OutArea/@v) &gt; 0 ">
				<xsl:element name="out_Domain.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:OutArea/@codingScheme|OutArea/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:OutArea/@v|OutArea/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ClassificationCategory">
		<xsl:choose>
			<xsl:when test="count(org:ClassificationCategory/@v|ClassificationCategory/@v) &gt; 0 ">
				<xsl:element name="auction.category">
					<xsl:value-of select="org:ClassificationCategory/@v|ClassificationCategory/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="AuctionIdentification">
		<xsl:choose>
			<xsl:when test="count(org:AuctionIdentification/@v|AuctionIdentification/@v) &gt; 0 ">
				<xsl:element name="auction.mRID">
					<xsl:value-of select="org:AuctionIdentification/@v|AuctionIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MeasureUnit">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnit/@v|MeasureUnit/@v) &gt; 0 ">
				<xsl:element name="measure_Unit.name">
					<xsl:value-of select="org:MeasureUnit/@v|MeasureUnit/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReasonCode">
		<xsl:element name="code">
			<xsl:value-of select="org:ReasonCode/@v|ReasonCode/@v"/>
		</xsl:element>
		<xsl:for-each select="org:ReasonText|ReasonText">
			<xsl:element name="text">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="TimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:TimeInterval/@v|TimeInterval/@v) &gt; 0 ">
				<xsl:element name="timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Resolution">
		<xsl:choose>
			<xsl:when test="count(org:Resolution/@v|Resolution/@v) &gt; 0 ">
				<xsl:element name="resolution">
					<xsl:value-of select="org:Resolution/@v|Resolution/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Pos">
		<xsl:choose>
			<xsl:when test="count(org:Pos/@v|Pos/@v) &gt; 0 ">
				<xsl:element name="position">
					<xsl:value-of select="org:Pos/@v|Pos/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Qty">
		<xsl:choose>
			<xsl:when test="count(org:Qty/@v|Qty/@v) &gt; 0 ">
				<xsl:element name="quantity">
					<xsl:value-of select="org:Qty/@v|Qty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="CurveType">
		<xsl:choose>
			<xsl:when test="count(org:CurveType/@v|CurveType/@v) &gt; 0 ">
				<xsl:element name="curveType">
					<xsl:value-of select="org:CurveType/@v|CurveType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ConnectingLine">
		<xsl:choose>
			<xsl:when test="count(org:ConnectingLine/@v|ConnectingLine/@v) &gt; 0 ">
				<xsl:element name="connectingLine_RegisteredResource.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:ConnectingLine/@codingScheme|ConnectingLine/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:ConnectingLine/@v|ConnectingLine/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
