<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:esp:energyaccountreport:1:2" xmlns="urn:iec62325.351:tc57wg16:451-4:energyaccountdocument:3:0" version="1.0" exclude-result-prefixes="org">
	<xsl:output method="xml"/>
		<!-- This xslt convert an ENTSO-E energy account report v1.0, v1.1 and v1.2 to a CIM energy account document v3.0-->
	<xsl:template match="org:EnergyAccountReport|EnergyAccountReport">
		<EnergyAccount_MarketDocument>
			<xsl:call-template name="DocumentIdentification"/>
			<xsl:call-template name="DocumentVersion"/>
			<xsl:call-template name="DocumentType"/>
			<xsl:call-template name="DocumentStatus"/>
			<xsl:call-template name="ProcessType"/>
			<xsl:call-template name="ClassificationType"/>
			<xsl:call-template name="SenderIdentification"/>
			<xsl:call-template name="SenderRole"/>
			<xsl:call-template name="ReceiverIdentification"/>
			<xsl:call-template name="ReceiverRole"/>
			<xsl:call-template name="DocumentDateTime"/>
			<xsl:call-template name="AccountingPeriod"/>
			<xsl:call-template name="Domain"/>
			<xsl:call-template name="AccountTimeSeries"/>
		</EnergyAccount_MarketDocument>
	</xsl:template>
	<xsl:template name="AccountTimeSeries">
		<xsl:for-each select="org:AccountTimeSeries|AccountTimeSeries">
			<xsl:element name="TimeSeries">
				<xsl:call-template name="SendersTimeSeriesIdentification"/>
				<xsl:call-template name="BusinessType"/>
				<xsl:call-template name="Product"/>
				<xsl:call-template name="ObjectAggregation"/>
				<xsl:call-template name="Area"/>
				<xsl:call-template name="Party"/>
				<xsl:call-template name="AgreementIdentification"/>
				<xsl:call-template name="MeasurementUnit"/>
				<xsl:call-template name="Currency"/>
				<xsl:call-template name="AccountingPoint"/>
				<xsl:call-template name="Period"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Period">
		<xsl:for-each select="org:Period|Period">
			<xsl:element name="Period">
				<xsl:call-template name="TimeInterval"/>
				<xsl:call-template name="Resolution"/>
				<xsl:call-template name="AccountInterval"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="AccountInterval">
		<xsl:for-each select="org:AccountInterval|AccountInterval">
			<xsl:element name="Point">
				<xsl:call-template name="Pos"/>
				<xsl:call-template name="InQty"/>
				<xsl:call-template name="OutQty"/>
				<xsl:call-template name="SettlementAmount"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!-- Entities Information -->
	<xsl:template name="DocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="DocumentVersion">
		<xsl:choose>
			<xsl:when test="count(org:DocumentVersion/@v|DocumentVersion/@v) &gt; 0 ">
				<xsl:element name="revisionNumber">
					<xsl:value-of select="org:DocumentVersion/@v|DocumentVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
    <xsl:template name="DocumentType">
		<xsl:choose>
			<xsl:when test="count(org:DocumentType/@v|DocumentType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:DocumentType/@v|DocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="DocumentStatus">
		<xsl:element name="docStatus">
			<xsl:element name="value">
				<xsl:value-of select="org:DocumentStatus/@v|DocumentStatus/@v"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<!-- -->
	<xsl:template name="ProcessType">
		<xsl:choose>
			<xsl:when test="count(org:ProcessType/@v|ProcessType/@v) &gt; 0 ">
				<xsl:element name="process.processType">
					<xsl:value-of select="org:ProcessType/@v|ProcessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="ClassificationType">
		<xsl:choose>
			<xsl:when test="count(org:ClassificationType/@v|ClassificationType/@v) &gt; 0 ">
				<xsl:element name="process.classificationType">
					<xsl:value-of select="org:ClassificationType/@v|ClassificationType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="SenderIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SenderIdentification/@v|SenderIdentification/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme">
					<xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="SenderRole">
		<xsl:choose>
			<xsl:when test="count(org:SenderRole/@v|SenderRole/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="ReceiverIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverIdentification/@v|ReceiverIdentification/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme">
					<xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="ReceiverRole">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverRole/@v|ReceiverRole/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="DocumentDateTime">
		<xsl:choose>
			<xsl:when test="count(org:DocumentDateTime/@v|DocumentDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:DocumentDateTime/@v|DocumentDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="AccountingPeriod">
		<xsl:choose>
			<xsl:when test="count(org:AccountingPeriod/@v|AccountingPeriod/@v) &gt; 0 ">
				<xsl:element name="period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:AccountingPeriod/@v|AccountingPeriod/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:AccountingPeriod/@v|AccountingPeriod/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="Domain">
		<xsl:choose>
			<xsl:when test="count(org:Domain/@codingScheme|Domain/@codingScheme) &gt; 0 ">
				<xsl:element name="domain.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:Domain/@codingScheme|Domain/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:Domain/@v|Domain/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="SendersTimeSeriesIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SendersTimeSeriesIdentification/@v|SendersTimeSeriesIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:SendersTimeSeriesIdentification/@v|SendersTimeSeriesIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="BusinessType">
		<xsl:choose>
			<xsl:when test="count(org:BusinessType/@v|BusinessType/@v) &gt; 0 ">
				<xsl:element name="businessType">
					<xsl:value-of select="org:BusinessType/@v|BusinessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="Product">
		<xsl:choose>
			<xsl:when test="count(org:Product/@v|Product/@v) &gt; 0 ">
				<xsl:element name="product">
					<xsl:value-of select="org:Product/@v|Product/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="ObjectAggregation">
		<xsl:choose>
			<xsl:when test="count(org:ObjectAggregation/@v|ObjectAggregation/@v) &gt; 0 ">
				<xsl:element name="objectAggregation">
					<xsl:value-of select="org:ObjectAggregation/@v|ObjectAggregation/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="Area">
		<xsl:choose>
			<xsl:when test="count(org:Area/@v|Area/@v) &gt; 0 ">
				<xsl:element name="area_Domain.mRID">
					<xsl:attribute name="codingScheme">
					<xsl:value-of select="org:Area/@codingScheme|Area/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:Area/@v|Area/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="Party">
		<xsl:choose>
			<xsl:when test="count(org:Party/@v|Party/@v) &gt; 0 ">
				<xsl:element name="marketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:Party/@codingScheme|Party/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:Party/@v|Party/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="AgreementIdentification">
		<xsl:choose>
			<xsl:when test="count(org:AgreementIdentification/@v|AgreementIdentification/@v) &gt; 0 ">
				<xsl:element name="marketAgreement.mRID">
					<xsl:value-of select="org:AgreementIdentification/@v|AgreementIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="MeasurementUnit">
		<xsl:choose>
			<xsl:when test="count(org:MeasurementUnit/@v|MeasurementUnit/@v) &gt; 0 ">
				<xsl:element name="measure_Unit.name">
					<xsl:value-of select="org:MeasurementUnit/@v|MeasurementUnit/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="Currency">
		<xsl:choose>
			<xsl:when test="count(org:Currency/@v|Currency/@v) &gt; 0 ">
				<xsl:element name="currency_Unit.name">
					<xsl:value-of select="org:Currency/@v|Currency/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="AccountingPoint">
		<xsl:choose>
			<xsl:when test="count(org:AccountingPoint/@v|AccountingPoint/@v) &gt; 0 ">
				<xsl:element name="marketEvaluationPoint.mRID">
					<xsl:attribute name="codingScheme">
					<xsl:value-of select="org:AccountingPoint/@codingScheme|AccountingPoint/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:AccountingPoint/@v|AccountingPoint/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
		<xsl:template name="TimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:TimeInterval/@v|TimeInterval/@v) &gt; 0 ">
				<xsl:element name="timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="Resolution">
		<xsl:choose>
			<xsl:when test="count(org:Resolution/@v|Resolution/@v) &gt; 0 ">
				<xsl:element name="resolution">
					<xsl:value-of select="org:Resolution/@v|Resolution/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="Pos">
		<xsl:choose>
			<xsl:when test="count(org:Pos/@v|Pos/@v) &gt; 0 ">
				<xsl:element name="position">
					<xsl:value-of select="org:Pos/@v|Pos/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="InQty">
		<xsl:choose>
			<xsl:when test="count(org:InQty/@v|InQty/@v) &gt; 0 ">
				<xsl:element name="quantity">
					<xsl:value-of select="org:InQty/@v|InQty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
		<xsl:template name="OutQty">
		<xsl:choose>
			<xsl:when test="count(org:OutQty/@v|OutQty/@v) &gt; 0 ">
				<xsl:element name="secondaryQuantity">
					<xsl:value-of select="org:OutQty/@v|OutQty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="SettlementAmount">
		<xsl:choose>
			<xsl:when test="count(org:SettlementAmount/@v|SettlementAmount/@v) &gt; 0 ">
				<xsl:element name="price.amount">
					<xsl:value-of select="org:SettlementAmount/@v|SettlementAmount/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
</xsl:stylesheet>
