<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:epsd:problemstatementdocument:2:1" xmlns="urn:iec62325.351:tc57wg16:451-5:problemdocument:3:0" version="1.0" exclude-result-prefixes="org">
	<xsl:output method="xml"/>
	<!-- This xslt convert an ENTSO-E problem statement document v2.0 and v2.1 to a CIM schedule document v3.0-->
	<xsl:template match="org:ProblemStatementDocument|ProblemStatementDocument">
		<ProblemStatement_MarketDocument>
			<xsl:call-template name="DocumentIdentification"/>
			<xsl:call-template name="DocumentVersion"/>
			<xsl:call-template name="DocumentType"/>
			<xsl:call-template name="SenderIdentification"/>
			<xsl:call-template name="SenderRole"/>
			<xsl:call-template name="ReceiverIdentification"/>
			<xsl:call-template name="ReceiverRole"/>
			<xsl:call-template name="CreationDateTime"/>
			<xsl:call-template name="RelatedTimeInterval"/>
			<xsl:call-template name="ExpectedDocumentType"/>
			<xsl:call-template name="ExpectedDocumentDeadline"/>
			<xsl:call-template name="ExpectedProcessType"/>
			<xsl:call-template name="ExpectedDeliveryDateTime"/>
			<xsl:call-template name="Domain"/>
			<xsl:call-template name="Reason"/>
		</ProblemStatement_MarketDocument>
	</xsl:template>
	<xsl:template name="Reason">
		<xsl:for-each select="org:Reason|Reason">
			<xsl:element name="Reason">
				<xsl:call-template name="ReasonCode"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!-- Entities Information -->
	<!-- DocumentIdentification -->
	<xsl:template name="DocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- DocumentVersion -->
	<xsl:template name="DocumentVersion">
		<xsl:choose>
			<xsl:when test="count(org:DocumentVersion/@v|DocumentVersion/@v) &gt; 0 ">
				<xsl:element name="revisionNumber">
					<xsl:value-of select="org:DocumentVersion/@v|DocumentVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- DocumentType -->
	<xsl:template name="DocumentType">
		<xsl:choose>
			<xsl:when test="count(org:DocumentType/@v|DocumentType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:DocumentType/@v|DocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- SenderIdentification -->
	<xsl:template name="SenderIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SenderIdentification/@v|SenderIdentification/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- SenderRole -->
	<xsl:template name="SenderRole">
		<xsl:choose>
			<xsl:when test="count(org:SenderRole/@v|SenderRole/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- ReceiverIdentification -->
	<xsl:template name="ReceiverIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverIdentification/@v|ReceiverIdentification/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- ReceiverRole -->
	<xsl:template name="ReceiverRole">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverRole/@v|ReceiverRole/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- CreationDateTime -->
	<xsl:template name="CreationDateTime">
		<xsl:choose>
			<xsl:when test="count(org:CreationDateTime/@v|CreationDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:CreationDateTime/@v|CreationDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- RelatedTimeInterval -->
	<xsl:template name="RelatedTimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:RelatedTimeInterval/@v|RelatedTimeInterval/@v) &gt; 0 ">
				<xsl:element name="period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:RelatedTimeInterval/@v|RelatedTimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:RelatedTimeInterval/@v|RelatedTimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- ExpectedDocumentType -->
	<xsl:template name="ExpectedDocumentType">
		<xsl:choose>
			<xsl:when test="count(org:ExpectedDocumentType/@v|ExpectedDocumentType/@v) &gt; 0 ">
				<xsl:element name="expected_MarketDocument.type">
					<xsl:value-of select="org:ExpectedDocumentType/@v|ExpectedDocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- ExpectedDocumentDeadline -->
	<xsl:template name="ExpectedDocumentDeadline">
		<xsl:choose>
			<xsl:when test="count(org:ExpectedDocumentDeadline/@v|ExpectedDocumentDeadline/@v) &gt; 0 ">
				<xsl:element name="expected_MarketDocument.createdDateTime">
					<xsl:value-of select="org:ExpectedDocumentDeadline/@v|ExpectedDocumentDeadline/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- ExpectedProcessType -->
	<xsl:template name="ExpectedProcessType">
		<xsl:choose>
			<xsl:when test="count(org:ExpectedProcessType/@v|ExpectedProcessType/@v) &gt; 0 ">
				<xsl:element name="expected_MarketDocument.process.processType">
					<xsl:value-of select="org:ExpectedProcessType/@v|ExpectedProcessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- ExpectedDeliveryDateTime -->
	<xsl:template name="ExpectedDeliveryDateTime">
		<xsl:choose>
			<xsl:when test="count(org:ExpectedDeliveryDateTime/@v|ExpectedDeliveryDateTime/@v) &gt; 0 ">
				<xsl:element name="delivery_MarketDocument.createdDateTime">
					<xsl:value-of select="org:ExpectedDeliveryDateTime/@v|ExpectedDeliveryDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- Domain -->
	<xsl:template name="Domain">
		<xsl:choose>
			<xsl:when test="count(org:Domain|Domain) &gt; 0 ">
				<xsl:element name="domain.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:Domain/@codingScheme|Domain/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:Domain/@v|Domain/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- ReasonCode -->
	<xsl:template name="ReasonCode">
		<xsl:element name="code">
			<xsl:value-of select="org:ReasonCode/@v|ReasonCode/@v"/>
		</xsl:element>
		<xsl:for-each select="org:ReasonText|ReasonText">
			<xsl:element name="text">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!-- -->
</xsl:stylesheet>
