<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:esr:statusrequestdocument:3:0" xmlns="urn:iec62325.351:tc57wg16:451-5:statusrequestdocument:4:0" version="1.0" exclude-result-prefixes="org">
	<xsl:output method="xml"/>
	<!-- This xslt convert an ENTSO-E status request document v2.0 or 3.0 into a CIM xsd v4.0 -->
	<xsl:template match="org:StatusRequestDocument|StatusRequestDocument">
		<StatusRequest_MarketDocument>
			<xsl:call-template name="DocumentIdentification"/>
			<xsl:call-template name="DocumentType"/>
			<xsl:call-template name="SenderIdentification"/>
			<xsl:call-template name="SenderRole"/>
			<xsl:call-template name="ReceiverIdentification"/>
			<xsl:call-template name="ReceiverRole"/>
			<xsl:call-template name="CreationDateTime"/>
			<xsl:call-template name="RequestComponent"/>
		</StatusRequest_MarketDocument>
	</xsl:template>
	<xsl:template name="RequestComponent">
		<xsl:for-each select="org:RequestComponent|RequestComponent">
			<xsl:element name="AttributeInstanceComponent">
				<xsl:call-template name="RequestedAttribute"/>
				<xsl:call-template name="RequestedAttributeValue"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!-- Entities Information -->
	<!-- DocumentIdentification -->
	<xsl:template name="DocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- DocumentType -->
	<xsl:template name="DocumentType">
		<xsl:choose>
			<xsl:when test="count(org:DocumentType/@v|DocumentType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:DocumentType/@v|DocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- SenderIdentification -->
	<xsl:template name="SenderIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SenderIdentification/@v|SenderIdentification/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- SenderRole -->
	<xsl:template name="SenderRole">
		<xsl:choose>
			<xsl:when test="count(org:SenderRole/@v|SenderRole/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- ReceiverIdentification -->
	<xsl:template name="ReceiverIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverIdentification/@v|ReceiverIdentification/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme">
						<xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- ReceiverRole -->
	<xsl:template name="ReceiverRole">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverRole/@v|ReceiverRole/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- CreationDateTime -->
	<xsl:template name="CreationDateTime">
		<xsl:choose>
			<xsl:when test="count(org:CreationDateTime/@v|CreationDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:CreationDateTime/@v|CreationDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- RequestedAttribute -->
	<xsl:template name="RequestedAttribute">
		<xsl:choose>
			<xsl:when test="count(org:RequestedAttribute/@v|RequestedAttribute/@v) &gt; 0 ">
				<xsl:element name="attribute">
					<xsl:value-of select="org:RequestedAttribute/@v|RequestedAttribute/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<!-- RequestedAttributeValue -->
	<xsl:template name="RequestedAttributeValue">
		<xsl:choose>
			<xsl:when test="count(org:RequestedAttributeValue/@v|RequestedAttributeValue/@v) &gt; 0 ">
				<xsl:element name="attributeValue">
					<xsl:choose>
						<xsl:when test="count(org:RequestedAttributeValue/@codingScheme|RequestedAttributeValue/@codingScheme) &gt; 0 ">
								<xsl:attribute name="codingScheme">
									<xsl:value-of select="org:RequestedAttributeValue/@codingScheme|RequestedAttributeValue/@codingScheme"/>
								</xsl:attribute>
						</xsl:when>
					</xsl:choose>
					<xsl:value-of select="org:RequestedAttributeValue/@v|RequestedAttributeValue/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
