<?xml version="1.0" encoding="UTF-8"?>
	<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:errp:historicactivationdocument:1:0" xmlns="urn:iec62325.351:tc57wg16:451-7:historicalactivationdocument:6:0" version="1.0"   exclude-result-prefixes="org">
	<xsl:output method="xml"/>
	<!-- This xsl convert an ENTSO-E   document  to a CIM  document -->
	<xsl:template match="org:HistoricActivationDocument|HistoricActivationDocument">
		<HistoricalActivation_MarketDocument>
			<xsl:call-template name="DocumentIdentification"/>
			<xsl:call-template name="DocumentVersion"/>
			<xsl:call-template name="DocumentType"/>
			<xsl:call-template name="ProcessType"/>
			<xsl:call-template name="SenderIdentification"/>
			<xsl:call-template name="SenderRole"/>
			<xsl:call-template name="ReceiverIdentification"/>
			<xsl:call-template name="ReceiverRole"/>
			<xsl:call-template name="CreationDateTime"/>
			<xsl:call-template name="ActivationTimeInterval"/>
			<xsl:call-template name="Domain"/>
			<xsl:call-template name="ActivationTimeSeries"/>
		</HistoricalActivation_MarketDocument>
	</xsl:template>
	<xsl:template name="ActivationTimeSeries">
		<xsl:for-each select="org:ActivationTimeSeries|ActivationTimeSeries">
			<xsl:element name="TimeSeries">
				<xsl:call-template name="ActivationIdentification"/>
				<xsl:call-template name="ActivationVersion"/>
				<xsl:call-template name="ActivationProcessType"/>
				<xsl:call-template name="RequestingParty"/>
				<xsl:call-template name="ActivatingParty"/>
	     		<xsl:call-template name="ActivationTimeIntervalTS"/>
	     		<xsl:call-template name="AllocationIdentification"/>
	     		<xsl:call-template name="ResourceProvider"/>
				<xsl:call-template name="BusinessType"/>
				<xsl:call-template name="AcquiringArea"/>
				<xsl:call-template name="ConnectingArea"/>
				<xsl:call-template name="MeasureUnit"/>
				<xsl:call-template name="Direction"/>
				<xsl:call-template name="Status"/>
				<xsl:call-template name="ResourceObject"/>
				<xsl:call-template name="Period"/>
				<xsl:call-template name="Reason"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Period">
		<xsl:for-each select="org:Period|Period">
			<xsl:element name="Period">
				<xsl:call-template name="TimeInterval"/>
				<xsl:call-template name="Resolution"/>
				<xsl:call-template name="Interval"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!--Period classes-->
	<xsl:template name="TimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:TimeInterval/@v|TimeInterval/@v) &gt; 0 ">
				<xsl:element name="timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Resolution">
		<xsl:choose>
			<xsl:when test="count(org:Resolution/@v|Resolution/@v) &gt; 0 ">
				<xsl:element name="resolution">
					<xsl:value-of select="org:Resolution/@v|Resolution/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Interval">
		<xsl:for-each select="org:Interval|Interval">
			<xsl:element name="Point">
				<xsl:call-template name="Pos"/>
				<xsl:call-template name="Qty"/>
				<xsl:call-template name="Reason"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Pos">
		<xsl:choose>
			<xsl:when test="count(org:Pos/@v|Pos/@v) &gt; 0 ">
				<xsl:element name="position">
					<xsl:value-of select="org:Pos/@v|Pos/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Qty">
		<xsl:choose>
			<xsl:when test="count(org:Qty/@v|Qty/@v) &gt; 0 ">
				<xsl:element name="quantity">
					<xsl:value-of select="org:Qty/@v|Qty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!--Reason classes-->
	<xsl:template name="Reason">
		<xsl:for-each select="org:Reason|Reason">
			<xsl:element name="Reason">
				<xsl:call-template name="ReasonCode"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="ReasonCode">
		<xsl:element name="code">
			<xsl:value-of select="org:ReasonCode/@v|ReasonCode/@v"/>
		</xsl:element>
		<xsl:for-each select="org:ReasonText|ReasonText">
			<xsl:element name="text">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!--MarketDocument classes-->
	<xsl:template name="DocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DocumentVersion">
		<xsl:choose>
			<xsl:when test="count(org:DocumentVersion/@v|DocumentVersion/@v) &gt; 0 ">
				<xsl:element name="revisionNumber">
					<xsl:value-of select="org:DocumentVersion/@v|DocumentVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DocumentType">
		<xsl:choose>
			<xsl:when test="count(org:DocumentType/@v|DocumentType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:DocumentType/@v|DocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ProcessType">
		<xsl:choose>
			<xsl:when test="count(org:ProcessType/@v|ProcessType/@v) &gt; 0 ">
				<xsl:element name="process.processType">
					<xsl:value-of select="org:ProcessType/@v|ProcessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SenderIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SenderIdentification/@v|SenderIdentification/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SenderRole">
		<xsl:choose>
			<xsl:when test="count(org:SenderRole/@v|SenderRole/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceiverIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverIdentification/@v|ReceiverIdentification/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceiverRole">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverRole/@v|ReceiverRole/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="CreationDateTime">
		<xsl:choose>
			<xsl:when test="count(org:CreationDateTime/@v|CreationDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:CreationDateTime/@v|CreationDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ActivationTimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:ActivationTimeInterval/@v|ActivationTimeInterval/@v) &gt; 0 ">
				<xsl:element name="time_Period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:ActivationTimeInterval/@v|ActivationTimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:ActivationTimeInterval/@v|ActivationTimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Domain">
		<xsl:for-each select="org:Domain|Domain">
			<xsl:element name="domain.mRID">
				<xsl:attribute name="codingScheme">
					<xsl:value-of select="@codingScheme"/>
				</xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!--TimeSeries classes-->
	<xsl:template name="ActivationIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ActivationIdentification/@v|ActivationIdentification/@v) &gt; 0 ">
				<xsl:element name="activation_Original_MarketDocument.mRID">
					<xsl:value-of select="org:ActivationIdentification/@v|ActivationIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ActivationVersion">
		<xsl:choose>
			<xsl:when test="count(org:ActivationVersion/@v|ActivationVersion/@v) &gt; 0 ">
				<xsl:element name="activation_Original_MarketDocument.revisionNumber">
					<xsl:value-of select="org:ActivationVersion/@v|ActivationVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ActivationProcessType">
		<xsl:choose>
			<xsl:when test="count(org:ActivationProcessType/@v|ActivationProcessType/@v) &gt; 0 ">
				<xsl:element name="activation_Original_MarketDocument.activation_Process.processType">
					<xsl:value-of select="org:ActivationProcessType/@v|ActivationProcessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="RequestingParty">
		<xsl:choose>
			<xsl:when test="count(org:RequestingParty/@v|RequestingParty/@v) &gt; 0 ">
				<xsl:element name="activation_Original_MarketDocument.requesting_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:RequestingParty/@codingScheme|RequestingParty/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:RequestingParty/@v|RequestingParty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ActivatingParty">
		<xsl:choose>
			<xsl:when test="count(org:ActivatingParty/@v|ActivatingParty/@v) &gt; 0 ">
				<xsl:element name="activation_Original_MarketDocument.activating_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:ActivatingParty/@codingScheme|ActivatingParty/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ActivatingParty/@v|ActivatingParty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
		<xsl:template name="ActivationTimeIntervalTS">
		<xsl:choose>
			<xsl:when test="count(org:ActivationTimeInterval/@v|ActivationTimeInterval/@v) &gt; 0 ">
				<xsl:element name="activation_Original_MarketDocument.activationTime_Period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:ActivationTimeInterval/@v|ActivationTimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:ActivationTimeInterval/@v|ActivationTimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="AllocationIdentification">
		<xsl:choose>
			<xsl:when test="count(org:AllocationIdentification/@v|AllocationIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:AllocationIdentification/@v|AllocationIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ResourceProvider">
		<xsl:choose>
			<xsl:when test="count(org:ResourceProvider/@v|ResourceProvider/@v) &gt; 0 ">
				<xsl:element name="resourceProvider_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:ResourceProvider/@codingScheme|ResourceProvider/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ResourceProvider/@v|ResourceProvider/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="BusinessType">
		<xsl:choose>
			<xsl:when test="count(org:BusinessType/@v|BusinessType/@v) &gt; 0 ">
				<xsl:element name="businessType">
					<xsl:value-of select="org:BusinessType/@v|BusinessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
			<xsl:template name="AcquiringArea">
		<xsl:for-each select="org:AcquiringArea|AcquiringArea">
			<xsl:element name="acquiring_Domain.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
			<xsl:template name="ConnectingArea">
		<xsl:for-each select="org:ConnectingArea|ConnectingArea">
			<xsl:element name="connecting_Domain.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
		<xsl:template name="MeasureUnit">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnit/@v|MeasureUnit/@v) &gt; 0 ">
				<xsl:element name="measurement_Unit.name">
					<xsl:value-of select="org:MeasureUnit/@v|MeasureUnit/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Direction">
		<xsl:choose>
			<xsl:when test="count(org:Direction/@v|Direction/@v) &gt; 0 ">
				<xsl:element name="flowDirection.direction">
					<xsl:value-of select="org:Direction/@v|Direction/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
		<xsl:template name="Status">
		<xsl:choose>
			<xsl:when test="count(org:Status/@v|Status/@v) &gt; 0 ">
				<xsl:element name="marketObjectStatus.status">
					<xsl:value-of select="org:Status/@v|Status/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ResourceObject">
		<xsl:for-each select="org:ResourceObject|ResourceObject">
			<xsl:element name="registeredResource.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
</xsl:stylesheet>
