<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:errp:moldocument:5:0" xmlns="urn:iec62325.351:tc57wg16:451-7:moldocument:6:0" version="1.0" exclude-result-prefixes="org">
	<xsl:output method="xml"/>
	<!-- This xsl convert an ENTSO-E MOL document version 5 to a CIM  document version 6 -->
	<xsl:template match="org:MolDocument|MolDocument">
		<MeritOrderList_MarketDocument>
			<xsl:call-template name="DocumentIdentification"/>
			<xsl:call-template name="DocumentVersion"/>
			<xsl:call-template name="DocumentType"/>
			<xsl:call-template name="ProcessType"/>
			<xsl:call-template name="SenderIdentification"/>
			<xsl:call-template name="SenderRole"/>
			<xsl:call-template name="ReceiverIdentification"/>
			<xsl:call-template name="ReceiverRole"/>
			<xsl:call-template name="CreationDateTime"/>
			<xsl:call-template name="ValidTimeInterval"/>
			<xsl:call-template name="Domain"/>
			<xsl:call-template name="MolTimeSeries"/>
		</MeritOrderList_MarketDocument>
	</xsl:template>
	<xsl:template name="MolTimeSeries">
		<xsl:for-each select="org:MolTimeSeries|MolTimeSeries">
			<xsl:element name="MOL_TimeSeries">
				<xsl:call-template name="ContractIdentification"/>
				<xsl:call-template name="TimeStamp"/>
				<xsl:call-template name="OrderNumber"/>
				<xsl:call-template name="ResourceProvider"/>
				<xsl:call-template name="ReserveObject"/>
				<xsl:call-template name="AcquiringArea"/>
				<xsl:call-template name="ConnectingArea"/>
				<xsl:call-template name="AuctionIdentification"/>
				<xsl:call-template name="BusinessType"/>
				<xsl:call-template name="BidTimeInterval"/>
				<xsl:call-template name="MeasureUnitQuantity"/>
				<xsl:call-template name="Currency"/>
				<xsl:call-template name="MeasureUnitPrice"/>
				<xsl:call-template name="MeasureUnitEnergyPrice"/>
				<xsl:call-template name="Direction"/>
				<xsl:call-template name="MinimumActivationQuantity"/>
				<xsl:call-template name="StepIncrementQuantity"/>
				<xsl:call-template name="Status"/>
				<xsl:call-template name="Period"/>
				<xsl:call-template name="Reason"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Period">
		<xsl:for-each select="org:Period|Period">
			<xsl:element name="Period">
				<xsl:call-template name="TimeInterval"/>
				<xsl:call-template name="Resolution"/>
				<xsl:call-template name="Interval"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Interval">
		<xsl:for-each select="org:Interval|Interval">
			<xsl:element name="Point">
				<xsl:call-template name="Pos"/>
				<xsl:call-template name="BidQty"/>
				<xsl:call-template name="PriceAmount"/>
				<xsl:call-template name="EnergyPrice"/>
				<xsl:call-template name="ActivatedQty"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Reason">
		<xsl:for-each select="org:Reason|Reason">
			<xsl:element name="Reason">
				<xsl:call-template name="ReasonCode"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="DocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DocumentVersion">
		<xsl:choose>
			<xsl:when test="count(org:DocumentVersion/@v|DocumentVersion/@v) &gt; 0 ">
				<xsl:element name="revisionNumber">
					<xsl:value-of select="org:DocumentVersion/@v|DocumentVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DocumentType">
		<xsl:choose>
			<xsl:when test="count(org:DocumentType/@v|DocumentType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:DocumentType/@v|DocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ProcessType">
		<xsl:choose>
			<xsl:when test="count(org:ProcessType/@v|ProcessType/@v) &gt; 0 ">
				<xsl:element name="process.processType">
					<xsl:value-of select="org:ProcessType/@v|ProcessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SenderIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SenderIdentification/@v|SenderIdentification/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SenderRole">
		<xsl:choose>
			<xsl:when test="count(org:SenderRole/@v|SenderRole/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceiverIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverIdentification/@v|ReceiverIdentification/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceiverRole">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverRole/@v|ReceiverRole/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="CreationDateTime">
		<xsl:choose>
			<xsl:when test="count(org:CreationDateTime/@v|CreationDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:CreationDateTime/@v|CreationDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ValidTimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:ValidTimeInterval/@v|ValidTimeInterval/@v) &gt; 0 ">
				<xsl:element name="valid_Time_Period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:ValidTimeInterval/@v|ValidTimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:ValidTimeInterval/@v|ValidTimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Domain">
		<xsl:choose>
			<xsl:when test="count(org:Domain/@codingScheme|Domain/@codingScheme) &gt; 0 ">
				<xsl:element name="domain.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:Domain/@codingScheme|Domain/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:Domain/@v|Domain/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- Time Series -->
	<xsl:template name="ContractIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ContractIdentification/@v|ContractIdentification/@v) &gt; 0 ">
				<xsl:element name="marketAgreement.mRID">
					<xsl:value-of select="org:ContractIdentification/@v|ContractIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="TimeStamp">
		<xsl:choose>
			<xsl:when test="count(org:TimeStamp/@v|TimeStamp/@v) &gt; 0 ">
				<xsl:element name="marketAgreement.createdDateTime">
					<xsl:value-of select="org:TimeStamp/@v|TimeStamp/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="OrderNumber">
		<xsl:choose>
			<xsl:when test="count(org:OrderNumber/@v|OrderNumber/@v) &gt; 0 ">
				<xsl:element name="orderNumber_AttributeInstanceComponent.position">
					<xsl:value-of select="org:OrderNumber/@v|OrderNumber/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ResourceProvider">
		<xsl:choose>
			<xsl:when test="count(org:ResourceProvider/@v|ResourceProvider/@v) &gt; 0 ">
				<xsl:element name="resourceProvider_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:ResourceProvider/@codingScheme|ResourceProvider/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ResourceProvider/@v|ResourceProvider/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReserveObject">
		<xsl:choose>
			<xsl:when test="count(org:ReserveObject/@v|ReserveObject/@v) &gt; 0 ">
				<xsl:element name="registeredResource.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:ReserveObject/@codingScheme|ReserveObject/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ReserveObject/@v|ReserveObject/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="AcquiringArea">
		<xsl:choose>
			<xsl:when test="count(org:AcquiringArea/@v|AcquiringArea/@v) &gt; 0 ">
				<xsl:element name="acquiring_Domain.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:AcquiringArea/@codingScheme|AcquiringArea/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:AcquiringArea/@v|AcquiringArea/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ConnectingArea">
		<xsl:choose>
			<xsl:when test="count(org:ConnectingArea/@v|ConnectingArea/@v) &gt; 0 ">
				<xsl:element name="connecting_Domain.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:ConnectingArea/@codingScheme|ConnectingArea/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ConnectingArea/@v|ConnectingArea/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="AuctionIdentification">
		<xsl:choose>
			<xsl:when test="count(org:AuctionIdentification/@v|AuctionIdentification/@v) &gt; 0 ">
				<xsl:element name="auction.mRID">
					<xsl:value-of select="org:AuctionIdentification/@v|AuctionIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="BusinessType">
		<xsl:choose>
			<xsl:when test="count(org:BusinessType/@v|BusinessType/@v) &gt; 0 ">
				<xsl:element name="businessType">
					<xsl:value-of select="org:BusinessType/@v|BusinessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="BidTimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:BidTimeInterval/@v|BidTimeInterval/@v) &gt; 0 ">
				<xsl:element name="bid_Period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:BidTimeInterval/@v|BidTimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:BidTimeInterval/@v|BidTimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MeasureUnitQuantity">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnitQuantity/@v|MeasureUnitQuantity/@v) &gt; 0 ">
				<xsl:element name="quantityMeasurement_Unit.name">
					<xsl:value-of select="org:MeasureUnitQuantity/@v|MeasureUnitQuantity/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Currency">
		<xsl:choose>
			<xsl:when test="count(org:Currency/@v|Currency/@v) &gt; 0 ">
				<xsl:element name="currency_Unit.name">
					<xsl:value-of select="org:Currency/@v|Currency/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
		<xsl:template name="MeasureUnitPrice">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnitPrice/@v|MeasureUnitPrice/@v) &gt; 0 ">
				<xsl:element name="priceMeasurement_Unit.name">
					<xsl:value-of select="org:MeasureUnitPrice/@v|MeasureUnitPrice/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MeasureUnitEnergyPrice">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnitEnergyPrice/@v|MeasureUnitEnergyPrice/@v) &gt; 0 ">
				<xsl:element name="energyPriceMeasurement_Unit.name">
					<xsl:value-of select="org:MeasureUnitEnergyPrice/@v|MeasureUnitEnergyPrice/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Direction">
		<xsl:choose>
			<xsl:when test="count(org:Direction/@v|Direction/@v) &gt; 0 ">
				<xsl:element name="flowDirection.direction">
					<xsl:value-of select="org:Direction/@v|Direction/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MinimumActivationQuantity">
		<xsl:choose>
			<xsl:when test="count(org:MinimumActivationQuantity/@v|MinimumActivationQuantity/@v) &gt; 0 ">
				<xsl:element name="minimumActivation_Quantity.quantity">
					<xsl:value-of select="org:MinimumActivationQuantity/@v|MinimumActivationQuantity/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="StepIncrementQuantity">
		<xsl:choose>
			<xsl:when test="count(org:StepIncrementQuantity/@v|StepIncrementQuantity/@v) &gt; 0 ">
				<xsl:element name="stepIncrement_Quantity.quantity">
					<xsl:value-of select="org:StepIncrementQuantity/@v|StepIncrementQuantity/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Status">
		<xsl:choose>
			<xsl:when test="count(org:Status/@v|Status/@v) &gt; 0 ">
				<xsl:element name="marketObjectStatus.status">
					<xsl:value-of select="org:Status/@v|Status/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReasonCode">
		<xsl:element name="code">
			<xsl:value-of select="org:ReasonCode/@v|ReasonCode/@v"/>
		</xsl:element>
		<xsl:for-each select="org:ReasonText|ReasonText">
			<xsl:element name="text">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="TimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:TimeInterval/@v|TimeInterval/@v) &gt; 0 ">
				<xsl:element name="timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Resolution">
		<xsl:choose>
			<xsl:when test="count(org:Resolution/@v|Resolution/@v) &gt; 0 ">
				<xsl:element name="resolution">
					<xsl:value-of select="org:Resolution/@v|Resolution/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Pos">
		<xsl:choose>
			<xsl:when test="count(org:Pos/@v|Pos/@v) &gt; 0 ">
				<xsl:element name="position">
					<xsl:value-of select="org:Pos/@v|Pos/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="BidQty">
		<xsl:choose>
			<xsl:when test="count(org:BidQty/@v|BidQty/@v) &gt; 0 ">
				<xsl:element name="quantity">
					<xsl:value-of select="org:BidQty/@v|BidQty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
		<xsl:choose>
			<xsl:when test="count(org:Qty/@v|Qty/@v) &gt; 0 ">
				<xsl:element name="quantity">
					<xsl:value-of select="org:Qty/@v|Qty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="PriceAmount">
		<xsl:choose>
			<xsl:when test="count(org:PriceAmount/@v|PriceAmount/@v) &gt; 0 ">
				<xsl:element name="price.amount">
					<xsl:value-of select="org:PriceAmount/@v|PriceAmount/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="EnergyPrice">
		<xsl:choose>
			<xsl:when test="count(org:EnergyPrice/@v|EnergyPrice/@v) &gt; 0 ">
				<xsl:element name="energy_Price.amount">
					<xsl:value-of select="org:EnergyPrice/@v|EnergyPrice/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ActivatedQty">
		<xsl:choose>
			<xsl:when test="count(org:ActivatedQty/@v|ActivatedQty/@v) &gt; 0 ">
				<xsl:element name="activated_Quantity.quantity">
					<xsl:value-of select="org:ActivatedQty/@v|ActivatedQty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
