<?xml version="1.0" encoding="UTF-8"?>
	<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:errp:redispatchdocument:5:0" xmlns="urn:iec62325.351:tc57wg16:451-7:redispatchdocument:6:0" version="1.0"   exclude-result-prefixes="org">
	<xsl:output method="xml"/>
	<!-- This xsl convert an ENTSO-E   document  to a CIM  document -->
	<xsl:template match="org:RedispatchDocument|RedispatchDocument">
		<Redispatch_MarketDocument>
			<xsl:call-template name="DocumentIdentification"/>
			<xsl:call-template name="DocumentVersion"/>
			<xsl:call-template name="DocumentType"/>
			<xsl:call-template name="SenderIdentification"/>
			<xsl:call-template name="SenderRole"/>
			<xsl:call-template name="ReceiverIdentification"/>
			<xsl:call-template name="ReceiverRole"/>
			<xsl:call-template name="CreationDateTime"/>
			<xsl:call-template name="RedispatchTimeInterval"/>
			<xsl:call-template name="Domain"/>
			<xsl:call-template name="SubjectParty"/>
			<xsl:call-template name="SubjectRole"/>
			<xsl:call-template name="RedispatchTimeSeries"/>
			<xsl:call-template name="Reason"/>
		</Redispatch_MarketDocument>
	</xsl:template>
	<xsl:template name="RedispatchTimeSeries">
		<xsl:for-each select="org:RedispatchTimeSeries|RedispatchTimeSeries">
			<xsl:element name="TimeSeries">
				<xsl:call-template name="TSIdentification"/>
				<xsl:call-template name="DispatcherName"/>
				<xsl:call-template name="BusinessType"/>
				<xsl:call-template name="ImpactedArea"/>
				<xsl:call-template name="Direction"/>
				<xsl:call-template name="MeasureUnitQuantity"/>
				<xsl:call-template name="BaseContractIdentification"/>
				<xsl:call-template name="ResourceObject"/>
				<xsl:call-template name="Currency"/>
				<xsl:call-template name="MeasureUnitPrice"/>
				<xsl:call-template name="TotalAmount"/>
				<xsl:call-template name="AmountDirection"/>
				<xsl:call-template name="Period"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Period">
		<xsl:for-each select="org:Period|Period">
			<xsl:element name="Period">
				<xsl:call-template name="TimeInterval"/>
				<xsl:call-template name="Resolution"/>
				<xsl:call-template name="Interval"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!--Period classes-->
	<xsl:template name="TimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:TimeInterval/@v|TimeInterval/@v) &gt; 0 ">
				<xsl:element name="timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Resolution">
		<xsl:choose>
			<xsl:when test="count(org:Resolution/@v|Resolution/@v) &gt; 0 ">
				<xsl:element name="resolution">
					<xsl:value-of select="org:Resolution/@v|Resolution/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Interval">
		<xsl:for-each select="org:Interval|Interval">
			<xsl:element name="Point">
				<xsl:call-template name="Pos"/>
				<xsl:call-template name="Qty"/>
				<xsl:call-template name="PriceCategory"/>
				<xsl:call-template name="Price"/>
				<xsl:call-template name="PriceDirection"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Pos">
		<xsl:choose>
			<xsl:when test="count(org:Pos/@v|Pos/@v) &gt; 0 ">
				<xsl:element name="position">
					<xsl:value-of select="org:Pos/@v|Pos/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Qty">
		<xsl:choose>
			<xsl:when test="count(org:Qty/@v|Qty/@v) &gt; 0 ">
				<xsl:element name="quantity">
					<xsl:value-of select="org:Qty/@v|Qty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="PriceCategory">
		<xsl:choose>
			<xsl:when test="count(org:PriceCategory/@v|PriceCategory/@v) &gt; 0 ">
				<xsl:element name="price.category">
					<xsl:value-of select="org:PriceCategory/@v|PriceCategory/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Price">
		<xsl:choose>
			<xsl:when test="count(org:Price/@v|Price/@v) &gt; 0 ">
				<xsl:element name="price.amount">
					<xsl:value-of select="org:Price/@v|Price/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="PriceDirection">
		<xsl:choose>
			<xsl:when test="count(org:PriceDirection/@v|PriceDirection/@v) &gt; 0 ">
				<xsl:element name="price.direction">
					<xsl:value-of select="org:PriceDirection/@v|PriceDirection/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!--Reason classes-->
	<xsl:template name="Reason">
		<xsl:for-each select="org:Reason|Reason">
			<xsl:element name="Reason">
				<xsl:call-template name="ReasonCode"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="ReasonCode">
		<xsl:element name="code">
			<xsl:value-of select="org:ReasonCode/@v|ReasonCode/@v"/>
		</xsl:element>
		<xsl:for-each select="org:ReasonText|ReasonText">
			<xsl:element name="text">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!--MarketDocument classes-->
	<xsl:template name="DocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DocumentVersion">
		<xsl:choose>
			<xsl:when test="count(org:DocumentVersion/@v|DocumentVersion/@v) &gt; 0 ">
				<xsl:element name="revisionNumber">
					<xsl:value-of select="org:DocumentVersion/@v|DocumentVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DocumentType">
		<xsl:choose>
			<xsl:when test="count(org:DocumentType/@v|DocumentType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:DocumentType/@v|DocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SenderIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SenderIdentification/@v|SenderIdentification/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SenderRole">
		<xsl:choose>
			<xsl:when test="count(org:SenderRole/@v|SenderRole/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceiverIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverIdentification/@v|ReceiverIdentification/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceiverRole">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverRole/@v|ReceiverRole/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="CreationDateTime">
		<xsl:choose>
			<xsl:when test="count(org:CreationDateTime/@v|CreationDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:CreationDateTime/@v|CreationDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="RedispatchTimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:RedispatchTimeInterval/@v|RedispatchTimeInterval/@v) &gt; 0 ">
				<xsl:element name="redispatch_Time_Period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:RedispatchTimeInterval/@v|RedispatchTimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:RedispatchTimeInterval/@v|RedispatchTimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Domain">
		<xsl:for-each select="org:Domain|Domain">
			<xsl:element name="domain.mRID">
				<xsl:attribute name="codingScheme">
					<xsl:value-of select="@codingScheme"/>
				</xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
		<xsl:template name="SubjectParty">
		<xsl:choose>
			<xsl:when test="count(org:SubjectParty/@v|SubjectParty/@v) &gt; 0 ">
				<xsl:element name="subject_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:SubjectParty/@codingScheme|SubjectParty/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:SubjectParty/@v|SubjectParty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SubjectRole">
		<xsl:choose>
			<xsl:when test="count(org:SubjectRole/@v|SubjectRole/@v) &gt; 0 ">
				<xsl:element name="subject_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SubjectRole/@v|SubjectRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!--TimeSeries classes-->
	<xsl:template name="TSIdentification">
		<xsl:choose>
			<xsl:when test="count(org:TSIdentification/@v|TSIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:TSIdentification/@v|TSIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
		<xsl:template name="DispatcherName">
		<xsl:choose>
			<xsl:when test="count(org:DispatcherName/@v|DispatcherName/@v) &gt; 0 ">
				<xsl:element name="dispatcher_MarketParticipant.name">
					<xsl:value-of select="org:DispatcherName/@v|DispatcherName/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="BusinessType">
		<xsl:choose>
			<xsl:when test="count(org:BusinessType/@v|BusinessType/@v) &gt; 0 ">
				<xsl:element name="businessType">
					<xsl:value-of select="org:BusinessType/@v|BusinessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
			<xsl:template name="ImpactedArea">
		<xsl:for-each select="org:ImpactedArea|ImpactedArea">
			<xsl:element name="impacted_Domain.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Direction">
		<xsl:choose>
			<xsl:when test="count(org:Direction/@v|Direction/@v) &gt; 0 ">
				<xsl:element name="flowDirection.direction">
					<xsl:value-of select="org:Direction/@v|Direction/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MeasureUnitQuantity">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnitQuantity/@v|MeasureUnitQuantity/@v) &gt; 0 ">
				<xsl:element name="measurement_Unit.name">
					<xsl:value-of select="org:MeasureUnitQuantity/@v|MeasureUnitQuantity/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
		<xsl:template name="BaseContractIdentification">
		<xsl:choose>
			<xsl:when test="count(org:BaseContractIdentification/@v|BaseContractIdentification/@v) &gt; 0 ">
				<xsl:element name="marketAgreement.mRID">
					<xsl:value-of select="org:BaseContractIdentification/@v|BaseContractIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ResourceObject">
		<xsl:for-each select="org:ResourceObject|ResourceObject">
			<xsl:element name="registeredResource.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Currency">
		<xsl:choose>
			<xsl:when test="count(org:Currency/@v|Currency/@v) &gt; 0 ">
				<xsl:element name="currency_Unit.name">
					<xsl:value-of select="org:Currency/@v|Currency/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MeasureUnitPrice">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnitPrice/@v|MeasureUnitPrice/@v) &gt; 0 ">
				<xsl:element name="price_Measurement_Unit.name">
					<xsl:value-of select="org:MeasureUnitPrice/@v|MeasureUnitPrice/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="TotalAmount">
		<xsl:choose>
			<xsl:when test="count(org:TotalAmount/@v|TotalAmount/@v) &gt; 0 ">
				<xsl:element name="total_Price.amount">
					<xsl:value-of select="org:TotalAmount/@v|TotalAmount/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="AmountDirection">
		<xsl:choose>
			<xsl:when test="count(org:AmountDirection/@v|AmountDirection/@v) &gt; 0 ">
				<xsl:element name="total_Price.direction">
					<xsl:value-of select="org:AmountDirection/@v|AmountDirection/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
