<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:errp:reservebiddocument:5:0" xmlns="urn:iec62325.351:tc57wg16:451-7:reservebiddocument:6:0" version="1.0"   exclude-result-prefixes="org">
	<xsl:output method="xml"/>
	<!-- This xsl convert an ENTSO-E   document  to a CIM  document -->
	<xsl:template match="org:ReserveBidDocument|ReserveBidDocument">
		<ReserveBid_MarketDocument>
			<xsl:call-template name="DocumentIdentification"/>
			<xsl:call-template name="DocumentVersion"/>
			<xsl:call-template name="DocumentType"/>
			<xsl:call-template name="ProcessType"/>
			<xsl:call-template name="SenderIdentification"/>
			<xsl:call-template name="SenderRole"/>
			<xsl:call-template name="ReceiverIdentification"/>
			<xsl:call-template name="ReceiverRole"/>
			<xsl:call-template name="CreationDateTime"/>
			<xsl:call-template name="ReserveBidTimeInterval"/>
			<xsl:call-template name="Domain"/>
			<xsl:call-template name="SubjectParty"/>
			<xsl:call-template name="SubjectRole"/>
			<xsl:call-template name="ReserveBidTimeSeries"/>
		</ReserveBid_MarketDocument>
	</xsl:template>
	<xsl:template name="ReserveBidTimeSeries">
		<xsl:for-each select="org:ReserveBidTimeSeries|ReserveBidTimeSeries">
			<xsl:element name="Bid_TimeSeries">
				<xsl:call-template name="ReserveBidIdentification"/>
				<xsl:call-template name="AuctionIdentification"/>
				<xsl:call-template name="BusinessType"/>
				<xsl:call-template name="AcquiringArea"/>
				<xsl:call-template name="ConnectingArea"/>
				<xsl:call-template name="MeasureUnitQuantity"/>
				<xsl:call-template name="Currency"/>
				<xsl:call-template name="MeasureUnitPrice"/>
				<xsl:call-template name="Divisible"/>
				<xsl:call-template name="LinkedBidsIdentification"/>
				<xsl:call-template name="BlockBid"/>
				<xsl:call-template name="ReserveObject"/>
				<xsl:call-template name="Direction"/>
				<xsl:call-template name="MinimumActivationQuantity"/>
				<xsl:call-template name="StepIncrementQuantity"/>
				<xsl:call-template name="MeasureUnitEnergyPrice"/>
				<xsl:call-template name="ContractType"/>
				<xsl:call-template name="ContractIdentification"/>
				<xsl:call-template name="ActivationDuration"/>
				<xsl:call-template name="RestingDuration"/>
				<xsl:call-template name="MinimumDuration"/>
				<xsl:call-template name="MaximumDuration"/>
				<xsl:call-template name="Period"/>
				<xsl:call-template name="AvailableMba"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Period">
		<xsl:for-each select="org:Period|Period">
			<xsl:element name="Period">
				<xsl:call-template name="TimeInterval"/>
				<xsl:call-template name="Resolution"/>
				<xsl:call-template name="Interval"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="AvailableMba">
		<xsl:for-each select="org:AvailableMba|AvailableMba">
			<xsl:element name="AvailableMBA_Domain">
				<xsl:call-template name="Area"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!--Period classes-->
	<xsl:template name="TimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:TimeInterval/@v|TimeInterval/@v) &gt; 0 ">
				<xsl:element name="timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Resolution">
		<xsl:choose>
			<xsl:when test="count(org:Resolution/@v|Resolution/@v) &gt; 0 ">
				<xsl:element name="resolution">
					<xsl:value-of select="org:Resolution/@v|Resolution/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Interval">
		<xsl:for-each select="org:Interval|Interval">
			<xsl:element name="Point">
				<xsl:call-template name="Pos"/>
				<xsl:call-template name="Qty"/>
				<xsl:call-template name="Price"/>
				<xsl:call-template name="EnergyPrice"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Pos">
		<xsl:choose>
			<xsl:when test="count(org:Pos/@v|Pos/@v) &gt; 0 ">
				<xsl:element name="position">
					<xsl:value-of select="org:Pos/@v|Pos/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Qty">
		<xsl:choose>
			<xsl:when test="count(org:Qty/@v|Qty/@v) &gt; 0 ">
				<xsl:element name="quantity">
					<xsl:value-of select="org:Qty/@v|Qty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Price">
		<xsl:choose>
			<xsl:when test="count(org:Price/@v|Price/@v) &gt; 0 ">
				<xsl:element name="price.amount">
					<xsl:value-of select="org:Price/@v|Price/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="EnergyPrice">
		<xsl:choose>
			<xsl:when test="count(org:EnergyPrice/@v|EnergyPrice/@v) &gt; 0 ">
				<xsl:element name="energy_Price.amount">
					<xsl:value-of select="org:EnergyPrice/@v|EnergyPrice/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Area">
		<xsl:for-each select="org:Area|Area">
			<xsl:element name="mRID">
				<xsl:attribute name="codingScheme">
					<xsl:value-of select="@codingScheme"/>
				</xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!--Reason classes-->
	<xsl:template name="Reason">
		<xsl:for-each select="org:Reason|Reason">
			<xsl:element name="Reason">
				<xsl:call-template name="ReasonCode"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="ReasonCode">
		<xsl:element name="code">
			<xsl:value-of select="org:ReasonCode/@v|ReasonCode/@v"/>
		</xsl:element>
		<xsl:for-each select="org:ReasonText|ReasonText">
			<xsl:element name="text">
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!--MarketDocument classes-->
	<xsl:template name="DocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DocumentVersion">
		<xsl:choose>
			<xsl:when test="count(org:DocumentVersion/@v|DocumentVersion/@v) &gt; 0 ">
				<xsl:element name="revisionNumber">
					<xsl:value-of select="org:DocumentVersion/@v|DocumentVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="DocumentType">
		<xsl:choose>
			<xsl:when test="count(org:DocumentType/@v|DocumentType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:DocumentType/@v|DocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ProcessType">
		<xsl:choose>
			<xsl:when test="count(org:ProcessType/@v|ProcessType/@v) &gt; 0 ">
				<xsl:element name="process.processType">
					<xsl:value-of select="org:ProcessType/@v|ProcessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SenderIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SenderIdentification/@v|SenderIdentification/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SenderRole">
		<xsl:choose>
			<xsl:when test="count(org:SenderRole/@v|SenderRole/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceiverIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverIdentification/@v|ReceiverIdentification/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReceiverRole">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverRole/@v|ReceiverRole/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="CreationDateTime">
		<xsl:choose>
			<xsl:when test="count(org:CreationDateTime/@v|CreationDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:CreationDateTime/@v|CreationDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReserveBidTimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:ReserveBidTimeInterval/@v|ReserveBidTimeInterval/@v) &gt; 0 ">
				<xsl:element name="reserveBid_Period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:ReserveBidTimeInterval/@v|ReserveBidTimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:ReserveBidTimeInterval/@v|ReserveBidTimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Domain">
		<xsl:for-each select="org:Domain|Domain">
			<xsl:element name="domain.mRID">
				<xsl:attribute name="codingScheme">
					<xsl:value-of select="@codingScheme"/>
				</xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="SubjectParty">
		<xsl:choose>
			<xsl:when test="count(org:SubjectParty/@v|SubjectParty/@v) &gt; 0 ">
				<xsl:element name="subject_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:SubjectParty/@codingScheme|SubjectParty/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:SubjectParty/@v|SubjectParty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="SubjectRole">
		<xsl:choose>
			<xsl:when test="count(org:SubjectRole/@v|SubjectRole/@v) &gt; 0 ">
				<xsl:element name="subject_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SubjectRole/@v|SubjectRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!--TimeSeries classes-->
	<xsl:template name="ReserveBidIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReserveBidIdentification/@v|ReserveBidIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:ReserveBidIdentification/@v|ReserveBidIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="AuctionIdentification">
		<xsl:choose>
			<xsl:when test="count(org:AuctionIdentification/@v|AuctionIdentification/@v) &gt; 0 ">
				<xsl:element name="auction.mRID">
					<xsl:value-of select="org:AuctionIdentification/@v|AuctionIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="BusinessType">
		<xsl:choose>
			<xsl:when test="count(org:BusinessType/@v|BusinessType/@v) &gt; 0 ">
				<xsl:element name="businessType">
					<xsl:value-of select="org:BusinessType/@v|BusinessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="AcquiringArea">
		<xsl:for-each select="org:AcquiringArea|AcquiringArea">
			<xsl:element name="acquiring_Domain.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="org:InArea|InArea">
			<xsl:element name="acquiring_Domain.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="ConnectingArea">
		<xsl:for-each select="org:ConnectingArea|ConnectingArea">
			<xsl:element name="connecting_Domain.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
		<xsl:for-each select="org:OutArea|OutArea">
			<xsl:element name="connecting_Domain.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>	
	<xsl:template name="MeasureUnitQuantity">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnitQuantity/@v|MeasureUnitQuantity/@v) &gt; 0 ">
				<xsl:element name="quantity_Measure_Unit.name">
					<xsl:value-of select="org:MeasureUnitQuantity/@v|MeasureUnitQuantity/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Currency">
		<xsl:choose>
			<xsl:when test="count(org:Currency/@v|Currency/@v) &gt; 0 ">
				<xsl:element name="currency_Unit.name">
					<xsl:value-of select="org:Currency/@v|Currency/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MeasureUnitPrice">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnitPrice/@v|MeasureUnitPrice/@v) &gt; 0 ">
				<xsl:element name="price_Measure_Unit.name">
					<xsl:value-of select="org:MeasureUnitPrice/@v|MeasureUnitPrice/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="Divisible">
		<xsl:choose>
			<xsl:when test="count(org:Divisible/@v|Divisible/@v) &gt; 0 ">
				<xsl:element name="divisible">
					<xsl:value-of select="org:Divisible/@v|Divisible/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="LinkedBidsIdentification">
		<xsl:choose>
			<xsl:when test="count(org:LinkedBidsIdentification/@v|LinkedBidsIdentification/@v) &gt; 0 ">
				<xsl:element name="linkedBidsIdentification">
					<xsl:value-of select="org:LinkedBidsIdentification/@v|LinkedBidsIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="BlockBid">
		<xsl:choose>
			<xsl:when test="count(org:BlockBid/@v|BlockBid/@v) &gt; 0 ">
				<xsl:element name="blockBid">
					<xsl:value-of select="org:BlockBid/@v|BlockBid/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ReserveObject">
		<xsl:for-each select="org:ReserveObject|ReserveObject">
			<xsl:element name="registeredResource.mRID">
				<xsl:attribute name="codingScheme"><xsl:value-of select="@codingScheme"/></xsl:attribute>
				<xsl:value-of select="@v"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Direction">
		<xsl:choose>
			<xsl:when test="count(org:Direction/@v|Direction/@v) &gt; 0 ">
				<xsl:element name="flowDirection.direction">
					<xsl:value-of select="org:Direction/@v|Direction/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MinimumActivationQuantity">
		<xsl:choose>
			<xsl:when test="count(org:MinimumActivationQuantity/@v|MinimumActivationQuantity/@v) &gt; 0 ">
				<xsl:element name="minimumActivationQuantity">
					<xsl:value-of select="org:MinimumActivationQuantity/@v|MinimumActivationQuantity/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="StepIncrementQuantity">
		<xsl:choose>
			<xsl:when test="count(org:StepIncrementQuantity/@v|StepIncrementQuantity/@v) &gt; 0 ">
				<xsl:element name="stepIncrementQuantity">
					<xsl:value-of select="org:StepIncrementQuantity/@v|StepIncrementQuantity/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MeasureUnitEnergyPrice">
		<xsl:choose>
			<xsl:when test="count(org:MeasureUnitEnergyPrice/@v|MeasureUnitEnergyPrice/@v) &gt; 0 ">
				<xsl:element name="energyPrice_Measure_Unit.name">
					<xsl:value-of select="org:MeasureUnitEnergyPrice/@v|MeasureUnitEnergyPrice/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ContractType">
		<xsl:choose>
			<xsl:when test="count(org:ContractType/@v|ContractType/@v) &gt; 0 ">
				<xsl:element name="marketAgreement.type">
					<xsl:value-of select="org:ContractType/@v|ContractType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ContractIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ContractIdentification/@v|ContractIdentification/@v) &gt; 0 ">
				<xsl:element name="marketAgreement.mRID">
					<xsl:value-of select="org:ContractIdentification/@v|ContractIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ActivationDuration">
		<xsl:choose>
			<xsl:when test="count(org:ActivationDuration/@v|ActivationDuration/@v) &gt; 0 ">
				<xsl:element name="activation_ConstraintDuration.duration">
					<xsl:value-of select="org:ActivationDuration/@v|ActivationDuration/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="RestingDuration">
		<xsl:choose>
			<xsl:when test="count(org:RestingDuration/@v|RestingDuration/@v) &gt; 0 ">
				<xsl:element name="resting_ConstraintDuration.duration">
					<xsl:value-of select="org:RestingDuration/@v|RestingDuration/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MinimumDuration">
		<xsl:choose>
			<xsl:when test="count(org:MinimumDuration/@v|MinimumDuration/@v) &gt; 0 ">
				<xsl:element name="minimum_ConstraintDuration.duration">
					<xsl:value-of select="org:MinimumDuration/@v|MinimumDuration/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="MaximumDuration">
		<xsl:choose>
			<xsl:when test="count(org:MaximumDuration/@v|MaximumDuration/@v) &gt; 0 ">
				<xsl:element name="maximum_ConstraintDuration.duration">
					<xsl:value-of select="org:MaximumDuration/@v|MaximumDuration/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
