<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:org="urn:entsoe.eu:wgedi:rgce:settlementdocument:1:2" xmlns="urn:iec62325.351:tc57wg16:451-n:rgcesettlementdocument:1:0" version="1.0" exclude-result-prefixes="org">
	<xsl:output method="xml"/>
		<!-- This xslt convert an ENTSO-E RgceSettlementDocument to a CIM RGCE settlement document v1.0-->
	<xsl:template match="org:RgceSettlementDocumentt|RgceSettlementDocument">
		<RGCEsettlement_MarketDocument>
			<xsl:call-template name="DocumentIdentification"/>
			<xsl:call-template name="DocumentVersion"/>
			<xsl:call-template name="DocumentType"/>
			<xsl:call-template name="ProcessType"/>
			<xsl:call-template name="SenderIdentification"/>
			<xsl:call-template name="SenderRole"/>
			<xsl:call-template name="ReceiverIdentification"/>
			<xsl:call-template name="ReceiverRole"/>
			<xsl:call-template name="DocumentDateTime"/>
			<xsl:call-template name="RecordingPeriod"/>
			<xsl:call-template name="CompensationPeriod"/>
			<xsl:call-template name="SubjectDomain"/>
			<xsl:call-template name="TimeSeries"/>
			<xsl:call-template name="DomainAccountPosition"/>
		</RGCEsettlement_MarketDocument>
	</xsl:template>
	<xsl:template name="TimeSeries">
		<xsl:for-each select="org:TimeSeries|TimeSeries">
			<xsl:element name="TimeSeries">
				<xsl:call-template name="TimeSeriesIdentification"/>
				<xsl:call-template name="BusinessType"/>
				<xsl:call-template name="Product"/>
				<xsl:call-template name="SubjectArea"/>
				<xsl:call-template name="Area"/>
				<xsl:call-template name="AccountingPoint"/>
				<xsl:call-template name="MeasurementUnit"/>
				<xsl:call-template name="Period"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Period">
		<xsl:for-each select="org:Period|Period">
			<xsl:element name="Period">
				<xsl:call-template name="TimeInterval"/>
				<xsl:call-template name="Resolution"/>
				<xsl:call-template name="Interval"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="Interval">
		<xsl:for-each select="org:Interval|Interval">
			<xsl:element name="Point">
				<xsl:call-template name="Pos"/>
				<xsl:call-template name="InQty"/>
				<xsl:call-template name="OutQty"/>
				<xsl:call-template name="aceTariffType"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="DomainAccountPosition">
		<xsl:for-each select="org:DomainAccountPosition|DomainAccountPosition">
			<xsl:element name="DomainAccount_AceTariffType">
				<xsl:call-template name="TariffType"/>
				<xsl:call-template name="OpeningPosition"/>
				<xsl:call-template name="ClosingPosition"/>
				<xsl:call-template name="CompensationPosition"/>
				<xsl:call-template name="MeasurementUnit"/>
			</xsl:element>
		</xsl:for-each>
	</xsl:template>
	<!-- Entities Information -->
	<xsl:template name="DocumentIdentification">
		<xsl:choose>
			<xsl:when test="count(org:DocumentIdentification/@v|DocumentIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:DocumentIdentification/@v|DocumentIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="DocumentVersion">
		<xsl:choose>
			<xsl:when test="count(org:DocumentVersion/@v|DocumentVersion/@v) &gt; 0 ">
				<xsl:element name="revisionNumber">
					<xsl:value-of select="org:DocumentVersion/@v|DocumentVersion/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
    <xsl:template name="DocumentType">
		<xsl:choose>
			<xsl:when test="count(org:DocumentType/@v|DocumentType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:DocumentType/@v|DocumentType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ProcessType">
		<xsl:choose>
			<xsl:when test="count(org:ProcessType/@v|ProcessType/@v) &gt; 0 ">
				<xsl:element name="process.processType">
					<xsl:value-of select="org:ProcessType/@v|ProcessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="SenderIdentification">
		<xsl:choose>
			<xsl:when test="count(org:SenderIdentification/@v|SenderIdentification/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme">
					<xsl:value-of select="org:SenderIdentification/@codingScheme|SenderIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:SenderIdentification/@v|SenderIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="SenderRole">
		<xsl:choose>
			<xsl:when test="count(org:SenderRole/@v|SenderRole/@v) &gt; 0 ">
				<xsl:element name="sender_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:SenderRole/@v|SenderRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="ReceiverIdentification">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverIdentification/@v|ReceiverIdentification/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.mRID">
					<xsl:attribute name="codingScheme">
					<xsl:value-of select="org:ReceiverIdentification/@codingScheme|ReceiverIdentification/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:ReceiverIdentification/@v|ReceiverIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="ReceiverRole">
		<xsl:choose>
			<xsl:when test="count(org:ReceiverRole/@v|ReceiverRole/@v) &gt; 0 ">
				<xsl:element name="receiver_MarketParticipant.marketRole.type">
					<xsl:value-of select="org:ReceiverRole/@v|ReceiverRole/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="DocumentDateTime">
		<xsl:choose>
			<xsl:when test="count(org:DocumentDateTime/@v|DocumentDateTime/@v) &gt; 0 ">
				<xsl:element name="createdDateTime">
					<xsl:value-of select="org:DocumentDateTime/@v|DocumentDateTime/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="RecordingPeriod">
		<xsl:choose>
			<xsl:when test="count(org:RecordingPeriod/@v|RecordingPeriod/@v) &gt; 0 ">
				<xsl:element name="recording_Period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:RecordingPeriod/@v|RecordingPeriod/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:RecordingPeriod/@v|RecordingPeriod/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="CompensationPeriod">
		<xsl:choose>
			<xsl:when test="count(org:CompensationPeriod/@v|CompensationPeriod/@v) &gt; 0 ">
				<xsl:element name="compensation_Period.timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:CompensationPeriod/@v|CompensationPeriod/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:CompensationPeriod/@v|CompensationPeriod/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="SubjectDomain">
		<xsl:choose>
			<xsl:when test="count(org:SubjectDomain/@codingScheme|SubjectDomain/@codingScheme) &gt; 0 ">
				<xsl:element name="domain.mRID">
					<xsl:attribute name="codingScheme"><xsl:value-of select="org:SubjectDomain/@codingScheme|SubjectDomain/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:Domain/@v|Domain/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="TimeSeriesIdentification">
		<xsl:choose>
			<xsl:when test="count(org:TimeSeriesIdentification/@v|TimeSeriesIdentification/@v) &gt; 0 ">
				<xsl:element name="mRID">
					<xsl:value-of select="org:TimeSeriesIdentification/@v|TimeSeriesIdentification/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="BusinessType">
		<xsl:choose>
			<xsl:when test="count(org:BusinessType/@v|BusinessType/@v) &gt; 0 ">
				<xsl:element name="businessType">
					<xsl:value-of select="org:BusinessType/@v|BusinessType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="Product">
		<xsl:choose>
			<xsl:when test="count(org:Product/@v|Product/@v) &gt; 0 ">
				<xsl:element name="product">
					<xsl:value-of select="org:Product/@v|Product/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="SubjectArea">
		<xsl:choose>
			<xsl:when test="count(org:SubjectArea/@v|SubjectArea/@v) &gt; 0 ">
				<xsl:element name="subject_Domain.mRID">
					<xsl:attribute name="codingScheme">
					<xsl:value-of select="org:SubjectArea/@codingScheme|SubjectArea/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:SubjectArea/@v|SubjectArea/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="Area">
		<xsl:choose>
			<xsl:when test="count(org:Area/@v|Area/@v) &gt; 0 ">
				<xsl:element name="area_Domain.mRID">
					<xsl:attribute name="codingScheme">
					<xsl:value-of select="org:Area/@codingScheme|Area/@codingScheme"/>
					</xsl:attribute>
					<xsl:value-of select="org:Area/@v|Area/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
<!-- -->
	<xsl:template name="AccountingPoint">
		<xsl:choose>
			<xsl:when test="count(org:AccountingPoint/@v|AccountingPoint/@v) &gt; 0 ">
				<xsl:element name="marketEvaluationPoint.mRID">
					<xsl:attribute name="codingScheme">
					<xsl:value-of select="org:AccountingPoint/@codingScheme|AccountingPoint/@codingScheme"/></xsl:attribute>
					<xsl:value-of select="org:AccountingPoint/@v|AccountingPoint/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="MeasurementUnit">
		<xsl:choose>
			<xsl:when test="count(org:MeasurementUnit/@v|MeasurementUnit/@v) &gt; 0 ">
				<xsl:element name="measure_Unit.name">
					<xsl:value-of select="org:MeasurementUnit/@v|MeasurementUnit/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
		<xsl:template name="TimeInterval">
		<xsl:choose>
			<xsl:when test="count(org:TimeInterval/@v|TimeInterval/@v) &gt; 0 ">
				<xsl:element name="timeInterval">
					<xsl:element name="start">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,1,17)"/>
					</xsl:element>
					<xsl:element name="end">
						<xsl:value-of select="substring(org:TimeInterval/@v|TimeInterval/@v,19,17)"/>
					</xsl:element>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="Resolution">
		<xsl:choose>
			<xsl:when test="count(org:Resolution/@v|Resolution/@v) &gt; 0 ">
				<xsl:element name="resolution">
					<xsl:value-of select="org:Resolution/@v|Resolution/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="Pos">
		<xsl:choose>
			<xsl:when test="count(org:Pos/@v|Pos/@v) &gt; 0 ">
				<xsl:element name="position">
					<xsl:value-of select="org:Pos/@v|Pos/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="InQty">
		<xsl:choose>
			<xsl:when test="count(org:InQty/@v|InQty/@v) &gt; 0 ">
				<xsl:element name="quantity">
					<xsl:value-of select="org:InQty/@v|InQty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
		<xsl:template name="OutQty">
		<xsl:choose>
			<xsl:when test="count(org:OutQty/@v|OutQty/@v) &gt; 0 ">
				<xsl:element name="secondaryQuantity">
					<xsl:value-of select="org:OutQty/@v|OutQty/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="aceTariffType">
		<xsl:choose>
			<xsl:when test="count(org:TariffType/@v|TariffType/@v) &gt; 0 ">
				<xsl:element name="aceTariffType.type">
					<xsl:value-of select="org:TariffType/@v|TariffType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="TariffType">
		<xsl:choose>
			<xsl:when test="count(org:TariffType/@v|TariffType/@v) &gt; 0 ">
				<xsl:element name="type">
					<xsl:value-of select="org:TariffType/@v|TariffType/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="OpeningPosition">
		<xsl:choose>
			<xsl:when test="count(org:OpeningPosition/@v|OpeningPosition/@v) &gt; 0 ">
				<xsl:element name="opening_Point.quantity">
					<xsl:value-of select="org:OpeningPosition/@v|OpeningPosition/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="ClosingPosition">
		<xsl:choose>
			<xsl:when test="count(org:ClosingPosition/@v|ClosingPosition/@v) &gt; 0 ">
				<xsl:element name="closing_Point.quantity">
					<xsl:value-of select="org:ClosingPosition/@v|ClosingPosition/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	<!-- -->
	<xsl:template name="CompensationPosition">
		<xsl:choose>
			<xsl:when test="count(org:CompensationPosition/@v|CompensationPosition/@v) &gt; 0 ">
				<xsl:element name="compensation_Point.quantity">
					<xsl:value-of select="org:CompensationPosition/@v|CompensationPosition/@v"/>
				</xsl:element>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
